@@ -1,7 +1,7 @@
 <?php
 /** 
-* ภาษาไทย เวอร์ชั่น 1.2.3 
-* 23/11/2553 
+* ภาษาไทย เวอร์ชั่น 1.3 
+* 27/8/2555 
 * ไฟล์ภาษาไทยสำหรับ PHPBB3 โดย www.mindphp.com และ www.phpbbthailand.com
 *
 */ 
@@ -111,7 +111,7 @@ $lang = array_merge($lang, array(
 	'MAX_AVATAR_SIZE'				=> 'ความกว้างยาวสูงสุดของภาพประจำตัว',
 	'MAX_AVATAR_SIZE_EXPLAIN'		=> 'ความกว้าง x ความสูง หน่วยพิกเซล',
 	'MAX_FILESIZE'					=> 'ขนาดไฟล์สูงสุดของภาพประจำตัว',
-	'MAX_FILESIZE_EXPLAIN'			=> 'สำหรับอัพโหลดไฟล์ภาพประจำตัว',
+	'MAX_FILESIZE_EXPLAIN'			=> 'สำหรับอัพโหลดไฟล์ภาพประจำตัว, ใส่ 0 คือไม่จำกัด, ไฟล์จะถูกจำกัดเพียงแค่จากการตั้งค่า PHP ของคุณ',
 	'MIN_AVATAR_SIZE'				=> 'ความกว้างยาวต่ำสุดของภาพประจำตัว ',
 	'MIN_AVATAR_SIZE_EXPLAIN'		=> 'ความกว้าง x ความสูง หน่วยเป็นพิกเซล',
 ));
@@ -242,10 +242,10 @@ $lang = array_merge($lang, array(
 	'ALLOW_EMAIL_REUSE_EXPLAIN'	=> 'ผู้ใช้คนละคนสามารถลงทะเบียนด้วย อีเมล เดียวกันได้',
 	'COPPA'						=> 'COPPA',
 	'COPPA_FAX'					=> 'COPPA fax number',
-	'COPPA_MAIL'				=> 'COPPA mailing address',
-	'COPPA_MAIL_EXPLAIN'		=> 'This is the mailing address where parents will send COPPA registration forms.',
+	'COPPA_MAIL'				=> 'ที่อยู่ติดต่อสำหรับ COPPA',
+	'COPPA_MAIL_EXPLAIN'		=> 'ที่อยู่ที่ผู้ปกครองจะส่งแบบฟอร์มการลงทะเบียน COPPA.',
 	'ENABLE_COPPA'				=> 'เปิดใช้งานการคุ้มครองข้อมูลของเด็ก',
-	'ENABLE_COPPA_EXPLAIN'		=> 'กำหนดให้สมาชิกอายุต่ำกว่า 13 ให้อยู่ภายใต้กฎหมายคุ้มครองข้อมูลส่วนบุคคลของเด็กของสหรัฐฯ. ถ้าไม่ได้เปิดให้งานข้อความแสดงกฏก็จะไม่ถูกแสดงขึ้นมา.',
+	'ENABLE_COPPA_EXPLAIN'		=> 'สหรัฐฯกำหนดให้ผู้ที่อายุต่ำกว่า 13 ปีอยู่ภายใต้กฎหมายคุ้มครองข้อมูลส่วนบุคคลของเด็ก. ถ้าไม่ได้เปิดใช้งานข้อความแสดงกฏก็จะไม่ถูกแสดงขึ้นมา.',
 	'MAX_CHARS'					=> 'สูงสุด',
 	'MIN_CHARS'					=> 'น้อยสุด',
 	'NO_AUTH_PLUGIN'			=> 'ไม่พบปลั๊กอิน auth .',
@@ -268,41 +268,41 @@ $lang = array_merge($lang, array(
 // Feeds
 $lang = array_merge($lang, array(
 	'ACP_FEED_MANAGEMENT'				=> 'ตั้งค่า Feeds ',
-	'ACP_FEED_MANAGEMENT_EXPLAIN'		=> 'โมดูลนี้ใช้สำหรับสร้าง ATOM Feeds, เป็นการแยก BBCode ในโพสออกเพื่อให้่อ่านได้จากเว็บอื่น..',
+	'ACP_FEED_MANAGEMENT_EXPLAIN'		=> 'โมดูลนี้ใช้สำหรับสร้าง ATOM Feeds, เป็นการแยก BBCode ในโพสออกเพื่อให้อ่านได้จากเว็บอื่น..',
 
 	'ACP_FEED_GENERAL'					=> 'ตั้งค่า Feeds',
-	'ACP_FEED_POST_BASED'				=> 'Post-based feed settings',
-	'ACP_FEED_TOPIC_BASED'				=> 'Topic-based feed settings',
-	'ACP_FEED_SETTINGS_OTHER'			=> 'Other feeds and settings',
+	'ACP_FEED_POST_BASED'				=> 'การตั้งค่า Post-based feed',
+	'ACP_FEED_TOPIC_BASED'				=> 'การตั้งค่า Topic-based feed',
+	'ACP_FEED_SETTINGS_OTHER'			=> 'การตั้งค่า feeds อื่นๆ',
 
 	'ACP_FEED_ENABLE'					=> 'เปิดใช้งาน feeds',
 	'ACP_FEED_ENABLE_EXPLAIN'			=> 'เปิดหรือปิดใช้งาน ATOM feeds ทั้งเว็บบอร์ด.<br />ถ้าตั้งค่าเป็น <strong>ไม่ทำงาน</strong> เป็นการปิด Feeds ทั้งหมด, ไม่ว่าตัวเลือกด้านล่าจะถูกตั้งค่าเป็นอะไรก็ตาม..',
 	'ACP_FEED_LIMIT'					=> 'จำนวนรายการ',
 	'ACP_FEED_LIMIT_EXPLAIN'			=> 'จำนวนสูงสุดที่กำหนดให้รายการใน feed .',
 
-	'ACP_FEED_OVERALL'					=> 'Enable board-wide feed',
-	'ACP_FEED_OVERALL_EXPLAIN'			=> 'Board-wide new posts.',
-	'ACP_FEED_FORUM'					=> 'Enable per-forum feeds',
-	'ACP_FEED_FORUM_EXPLAIN'			=> 'Single forum and subforums new posts.',
-	'ACP_FEED_TOPIC'					=> 'Enable per-topic feeds',
-	'ACP_FEED_TOPIC_EXPLAIN'			=> 'Single topics new posts.',
+	'ACP_FEED_OVERALL'					=> 'เปิดใช้ feed ทั่วทั้งบอร์ด',
+	'ACP_FEED_OVERALL_EXPLAIN'			=> 'แสดงผลโพสใหม่จากทุกเว็บบอร์ด',
+	'ACP_FEED_FORUM'					=> 'เปิดใช้ feeds ต่อบอร์ด',
+	'ACP_FEED_FORUM_EXPLAIN'			=> 'แสดงผลโพสใหม่จากบอร์ดเดี่ยวและบอร์ดย่อยภายในนั้น.',
+	'ACP_FEED_TOPIC'					=> 'เปิดใช้ feeds ต่อกระทู้',
+	'ACP_FEED_TOPIC_EXPLAIN'			=> 'แสดงผลกระทู้เดี่ยวและโพสใหม่',
 
-	'ACP_FEED_TOPICS_NEW'				=> 'Enable new topics feed',
-	'ACP_FEED_TOPICS_NEW_EXPLAIN'		=> 'Enables the “New Topics” feed, which displays the last created topics including the first post.',
-	'ACP_FEED_TOPICS_ACTIVE'			=> 'Enable active topics feed',
-	'ACP_FEED_TOPICS_ACTIVE_EXPLAIN'	=> 'Enables the “Active Topics” feed, which displays the last active topics including the last post.',
+	'ACP_FEED_TOPICS_NEW'				=> 'เปิดใช้ feed กระทู้ใหม่',
+	'ACP_FEED_TOPICS_NEW_EXPLAIN'		=> 'เปิดใช้งาน feed “กระทู้ใหม่” ซึ่งจะแสดงกระทู้ล่าสุดที่ถูกสร้างรวมถึงโพสแรก.',
+	'ACP_FEED_TOPICS_ACTIVE'			=> 'เปิดใช้ feed กระทู้ที่มีการเคลื่อนไหว',
+	'ACP_FEED_TOPICS_ACTIVE_EXPLAIN'	=> 'เปิดใช้งาน feed “กระทู้ที่มีการเคลื่อนไหว” ซึ่งจะแสดงกระทู้ล่าสุดที่มีการใช้งานรวมถึงโพสล่าสุด.',
 	'ACP_FEED_NEWS'						=> 'News feed',
-	'ACP_FEED_NEWS_EXPLAIN'				=> 'Pull the first post from these forums. Select no forums to disable news feed.<br />Select multiple forums by holding <samp>CTRL</samp> and clicking.',
+	'ACP_FEED_NEWS_EXPLAIN'				=> 'ดึงข้อมูลจากโพสแรกของบอร์ดเหล่านี้ ไม่เลือกเลยเพื่อปิดการทำงานของฟังชั่นนี้.<br />เลือกหลายๆบอร์ดโดยการกดปุ่ม <samp>CTRL</samp> ค้างและคลิกบอร์ดที่ต้องการ.',
 
-	'ACP_FEED_OVERALL_FORUMS'			=> 'Enable forums feed',
-	'ACP_FEED_OVERALL_FORUMS_EXPLAIN'	=> 'Enables the “All forums” feed, which displays a list of forums.',
+	'ACP_FEED_OVERALL_FORUMS'			=> 'เปิดใช้ forums feed',
+	'ACP_FEED_OVERALL_FORUMS_EXPLAIN'	=> 'เปิดใช้งาน “All forums” feed, ซึ่งจะแสดงรายการจำแนกของบอร์ด.',
 
-	'ACP_FEED_HTTP_AUTH'				=> 'Allow HTTP Authentication',
-	'ACP_FEED_HTTP_AUTH_EXPLAIN'		=> 'Enables HTTP authentication, which allows users to receive content that is hidden to guest users by adding the <samp>auth=http</samp> parameter to the feed URL. Please note that some PHP setups require additional changes to the .htaccess file. Instructions can be found in that file.',
+	'ACP_FEED_HTTP_AUTH'				=> 'อนุญาต HTTP Authentication',
+	'ACP_FEED_HTTP_AUTH_EXPLAIN'		=> 'เปิดใช้งาน HTTP authentication, ซึ่งอนุญาตให้ผู้ใช้รับข้อมูลที่ถูกซ่อนจาก guest users โดยการเพิ่ม parameter <samp>auth=http</samp> ไปยัง feed URL. หมายเหตุ: การตั้งค่า PHP บางส่วนจำเป็นต้องมีการแก้ไขเพิ่มเติมไฟล์ .htaccess คำแนะนำสามารถหาได้จากไฟล์นั้น.',
 	'ACP_FEED_ITEM_STATISTICS'			=> 'รายการสถิติ',
 	'ACP_FEED_ITEM_STATISTICS_EXPLAIN'	=> 'แสดงสถิติต่างๆถายใต้รายการ feed แต่ละรายการ<br />(เช่น. โพสโดย, วันและเวลา, ตอบกลับ, จำนวนที่เปิดดู)',
 	'ACP_FEED_EXCLUDE_ID'				=> 'ไม่รวมบอร์ดนี้',
-	'ACP_FEED_EXCLUDE_ID_EXPLAIN'		=> 'Content from these will be <strong>not included in feeds</strong>. Select no forum to pull data from all forums.<br />เลือกหรือยกเลิกการเลือกหลายๆบอร์ดพร้อมกันให้กด<samp>CTRL</samp>ค้างไว้แล้วคลิกบอร์ดที่ต้องการ.',	
+	'ACP_FEED_EXCLUDE_ID_EXPLAIN'		=> 'เนื้อหาจากบอร์ดนี้ <strong>จะไม่ถูกรวมอยู่ใน feeds</strong>. ไม่เลือกอะไรเลยเพื่อดึงข้อมูลจากทุกบอร์ดสำหรับ feeds.<br />เลือกหรือยกเลิกการเลือกหลายๆบอร์ดพร้อมกันให้กด<samp>CTRL</samp>ค้างไว้แล้วคลิกบอร์ดที่ต้องการ.',	
 ));
 
 
@@ -332,7 +332,7 @@ $lang = array_merge($lang, array(
 	'CAPTCHA_FONT_LOWER'					=> 'ใช้แบบอักษรตัวเล็ก',
 	'CAPTCHA_NO_GD'							=> 'ภาพอย่างง่าย',
 	'CAPTCHA_PREVIEW_MSG'			=> 'การเปลี่ยนแปลงของการตั้งค่ายังไม่ได้บันทึก. นี่เป็นเพียงตัวอย่าง.',
-	'CAPTCHA_PREVIEW_EXPLAIN'	=> 'ปลั๊กอินที่ใช้จะเ้หมือนกับที่เลือกอยู่ตอนนี้.',
+	'CAPTCHA_PREVIEW_EXPLAIN'	=> 'ปลั๊กอินที่ใช้จะเหมือนกับที่เลือกอยู่ตอนนี้.',
 
 	'CAPTCHA_SELECT'						=> 'ที่ติดตั้ง',
 	'CAPTCHA_SELECT_EXPLAIN'				=> 'ในลิสเป็นปลั๊กอินที่ได้รับการยอมรับในการใช้งาน. รายการที่เป็นสีเทาไม่สามารถเลือกใช้งานได้จำเป็นต้องตั้งค่ามันก่อนเลือกใช้งาน.',
@@ -343,10 +343,10 @@ $lang = array_merge($lang, array(
 
 	'VISUAL_CONFIRM_POST'					=> 'เปิดใช้ภาพยืนยันการโพสต์ สำหรับบุคคลทั่วไป ',
 	'VISUAL_CONFIRM_POST_EXPLAIN'			=> 'บุคคลทั่วไปจำเป็นต้องกรอกข้อความที่ถูกต้อง ตามภาพที่เห็นก่อนการโพสต์.',
-	'VISUAL_CONFIRM_REG'					=> 'ใช้การยืนยันภาพสำหรับการสมัครสมา่ชิก',
+	'VISUAL_CONFIRM_REG'					=> 'ใช้การยืนยันภาพสำหรับการสมัครสมาชิก',
 	'VISUAL_CONFIRM_REG_EXPLAIN'			=> 'บุคคลทั่วไปจำเป็นต้องกรอกข้อความที่ถูกต้อง ตามภาพที่เห็นในระหว่างการสมัครสมาชิก.',
-	'VISUAL_CONFIRM_REFRESH'				=> 'อนุึญาติืให้ผู้ใช้เป็นเลือกดูค่าใหม่',
-	'VISUAL_CONFIRM_REFRESH_EXPLAIN'		=> 'อนุึญาติืให้ผู้ใช้เป็นเลือกดูค่าใหม่ถ้าเขาไม่สามารถอ่านค่าที่เห็นอยู่ได้้. บางปลั๊กอินจะไม่มีตัวเลือกตรงนี้.',
+	'VISUAL_CONFIRM_REFRESH'				=> 'อนุญาติให้ผู้ใช้เป็นผู้เลือกดูค่าใหม่',
+	'VISUAL_CONFIRM_REFRESH_EXPLAIN'		=> 'อนุญาติให้ผู้ใช้เป็นผู้เลือกดูค่าใหม่ถ้าเขาไม่สามารถอ่านค่าที่เห็นอยู่ได้้. บางปลั๊กอินจะไม่มีตัวเลือกตรงนี้.',
 
 ));
 
@@ -357,10 +357,10 @@ $lang = array_merge($lang, array(
 	'COOKIE_DOMAIN'				=> 'โดเมนของ Cookie',
 	'COOKIE_NAME'				=> 'ชื่อของ Cookie',
 	'COOKIE_PATH'				=> 'พาร์ทของ Cookie',
-	'COOKIE_SECURE'				=> 'Cookie secure',
-	'COOKIE_SECURE_EXPLAIN'		=> 'ถ้าเซิร์ฟเวอร์รันผ่าน SSL ตั้งค่านี้เป็น enabled นอกนั้นปล่อยให้เป็น disabled การตั้งค่านี้ให้ enabled แต่ไม่ได้รันผ่าน SSL จะทำให้เซิร์ฟเวอร์ทำงานผิดพลาดขณะรีไดเรก',
+	'COOKIE_SECURE'				=> 'เข้ารหัส Cookie',
+	'COOKIE_SECURE_EXPLAIN'		=> 'ถ้าเซิร์ฟเวอร์รันผ่าน SSL ตั้งค่านี้ให้ เปิดใช้งาน ถ้าหากไม่ใช่ให้ตั้ง ไม่ทำงาน การตั้งค่านี้ให้ เปิดใช้งาน แต่ไม่ได้รันผ่าน SSL จะทำให้เซิร์ฟเวอร์ทำงานผิดพลาดขณะ Redirect',
 	'ONLINE_LENGTH'				=> 'ดูช่วงเวลาออนไลน์',
-	'ONLINE_LENGTH_EXPLAIN'		=> 'จำนวนนาทีที่ผู้ใช้ที่ไม่แอคทีฟ จะไม่ปรากฎในรายการ “Who is online” ค่าที่สูงยิ่งต้องการการประมวลผลมากขึ้นในการสร้างรายการ',
+	'ONLINE_LENGTH_EXPLAIN'		=> 'จำนวนนาทีที่ผู้ใช้ที่ไม่แอคทีฟ จะไม่ปรากฎในรายการ “ผู้ใช้งานขณะนี้” ค่าที่สูงยิ่งต้องการการประมวลผลมากขึ้นในการสร้างรายการ',
 	'SESSION_LENGTH'			=> 'อายุ Session',
 	'SESSION_LENGTH_EXPLAIN'	=> 'Sessions จะหมดอายุหลังจากเวลานี้,ในหน่วยวินาที',
 ));
@@ -374,10 +374,10 @@ $lang = array_merge($lang, array(
 	'LIMIT_LOAD_EXPLAIN'			=> 'ถ้าโหลดของระบบ ภายใน 1 นาที เกินค่าเฉลี่ย บอร์ดจะออฟไลน์  ค่า 1.0 เท่ากับ ~100% ของหนึ่งโปรเซสเซอร์ หน้าที่นี้ใช้ได้บน UNIX เซิร์ฟเวอร์  ค่านี้จะตั้งค่าตัวเองเป็น 0 ถ้า  phpBB ไม่สามารถตรวจสอบค่าโหลด',
 	'LIMIT_SESSIONS'				=> 'จำกัด sessions',
 	'LIMIT_SESSIONS_EXPLAIN'		=> 'ถ้า sessions ของระบบภายใน 1 นาที เกินกว่าค่านี้ บอร์ดจะออฟไลน์ ตั้งค่าเป็น 0 เพื่อไม่จำกัด sessions',
-	'LOAD_CPF_MEMBERLIST'			=> 'อนุญาติ styles สำหรับ profile ที่กำหนดเองใน memberlist',
+	'LOAD_CPF_MEMBERLIST'			=> 'อนุญาติ styles สำหรับโปรไฟล์ ที่กำหนดเองใน memberlist',
 	'LOAD_CPF_VIEWPROFILE'			=> 'แสดง custom profile fields ใน user profiles',
-	'LOAD_CPF_VIEWTOPIC'			=> 'แสดงข้อมูลที่กำหนดเองบน topic pages',
-	'LOAD_USER_ACTIVITY'			=> 'Show user’s activity',
+	'LOAD_CPF_VIEWTOPIC'			=> 'แสดงข้อมูลที่กำหนดเองบนหน้ากระทู้',
+	'LOAD_USER_ACTIVITY'			=> 'แสดงการใช้งานของผู้ใช้',
 	'LOAD_USER_ACTIVITY_EXPLAIN'	=> 'แสดงแอคทีฟ topic/forum ใน profiles ของผู้ใช้และ แป้นควบคุมผู้ใช้ ค่านี้แนะนำให้เลิกใช้ในบอร์ดที่มีโพสต์มากกว่าหนึ่งล้าน',
 	'RECOMPILE_STYLES'				=> 'Recompile stale style components',
 	'RECOMPILE_STYLES_EXPLAIN'		=> 'ตรวจสอบอัพเดทส่วนประกอบของรูปแบบบนระบบไฟล์และคอมไพล์ใหม่',
@@ -395,9 +395,9 @@ $lang = array_merge($lang, array(
 	'YES_ONLINE_GUESTS_EXPLAIN'		=> 'อนุญาตให้แสดงรายการ guest ออนไลน์',
 	'YES_ONLINE_TRACK'				=> 'อนุญาตการแสดงข้อมูลผู้ใช้ ออนไลน์/ออฟไลน์',
 	'YES_ONLINE_TRACK_EXPLAIN'		=> 'แสดงข้อมูลผู้ใช้ ออนไลน์/ออฟไลน์ สำหรับ profiles ผู้ใช้และหน้ากระทู้',
-	'YES_POST_MARKING'				=> 'Enable dotted topics',
+	'YES_POST_MARKING'				=> 'เปิดใช้ dotted topics',
 	'YES_POST_MARKING_EXPLAIN'		=> 'บ่งชี้ว่าผู้ใช้ได้ทำการโพสต์ในกระทู้แล้วหรือยัง',
-	'YES_READ_MARKING'				=> 'Enable เซิร์ฟเวอร์-side topic marking',
+	'YES_READ_MARKING'				=> 'เปิดใช้ เซิร์ฟเวอร์-side topic marking',
 	'YES_READ_MARKING_EXPLAIN'		=> 'เก็บสถานะอ่านแล้ว/ยังไม่ได้อ่าน ในฐานข้อมูลแทนการใช้คุกกี้',
 	'YES_UNREAD_SEARCH'				=> 'ให้คนหาโพสต์ที่ยังไม่ได้อ่าน',
 ));
@@ -411,7 +411,7 @@ $lang = array_merge($lang, array(
 	'APACHE_SETUP_BEFORE_USE'	=> 'คุณต้องตั้งค่า apache authentication ก่อนที่คุณ สลับไปใช้ phpBB จำไว้ว่าชื่อผู้ใช้ที่คุณใช้สำหรับ apache authentication ต้องเป็นอย่างเดียวกันกับ phpBB  Apache authentication สามารถใช้กับ mod_php (ไม่ใช้กับด้วยCGI version) และไม่ใช้ safe_mode ',
 
 	'LDAP_DN'						=> 'LDAP base <var>dn</var>',
-	'LDAP_DN_EXPLAIN'				=> 'This is the Distinguished Name, locating the user information, ตัวอย่างเช่น <samp>o=My Company,c=US</samp>.',
+	'LDAP_DN_EXPLAIN'				=> 'ชื่อพิเศษ, ใช้สำหรับระบุข้อมูลผู้ใช้, ตัวอย่างเช่น <samp>o=My Company,c=US</samp>.',
 	'LDAP_EMAIL'					=> 'LDAP e-mail attribute',
 	'LDAP_EMAIL_EXPLAIN'			=> 'ตั้งค่านี้ให้กับชื่อผู้ใช้ ในส่วน อีเมล (ถ้ามี) เพื่อที่จะตั้งค่า อีเมล ให้อัตโนมัติสำหรับผู้ใช้ใหม่ ปล่อยให้ค่านี้ว่าง ทำให้ส่วน อีเมล ของผู้ใช้ที่ล็อกอินครั้งแรกว่างด้วย',
 	'LDAP_INCORRECT_USER_PASSWORD'	=> 'ล้มเหลวในการผูกกับ LDAP เซิร์ฟเวอร์ ด้วย user/password ที่ระบุ',
@@ -419,18 +419,18 @@ $lang = array_merge($lang, array(
 	'LDAP_NO_IDENTITY'				=> 'หาล็อกอินสำหรับ %s ไม่เจอ',
 	'LDAP_PASSWORD'					=> 'รหัสผ่าน LDAP ',
 	'LDAP_PASSWORD_EXPLAIN'			=> 'ปล่อยค่านี้ให้ว่างเพื่อผูกแบบไม่กำหนดผู้ใช้หรือไม่ก็กรอก password สำหรับผู้ใช้ด้านบน ต้องการสำหรับแอคทีฟไดเรกทอรี่เซิร์ฟเวอร์ <strong>คำเตือน:</strong> password นี้จะเก็บเป็นข้อความธรรมดาใน ฐานข้อมูล ทุกคนที่เข้าถึงฐานข้อมูลได้ สามารถมองเห็นได้',
-	'LDAP_PASSWORD_EXPLAIN'			=> 'ปล่อยว่างไว้เพื่อใช้งานโดยไม่กำหนดผู้ใช้. กรอกรหัสสำหรับชื่อผู้ใช้ด้านบน. Required for Active Directory Servers.<br /><em><strong>คำเตือน:</strong>รหัสผ่านจะถูกเก็บเป็นข้อความธรรมดาลงในฐานข้อมูล.</em>',
+	'LDAP_PASSWORD_EXPLAIN'			=> 'ปล่อยว่างไว้เพื่อใช้งานโดยไม่กำหนดผู้ใช้. กรอกรหัสสำหรับชื่อผู้ใช้ด้านบน. จำเป็นสำหรับ Active Directory Servers.<br /><em><strong>คำเตือน:</strong>รหัสผ่านจะถูกเก็บเป็นข้อความธรรมดาลงในฐานข้อมูล.</em>',
 	
 	'LDAP_PORT'						=> 'พอร์ทของ LDAP เซิร์ฟเวอร์',
 	'LDAP_PORT_EXPLAIN'				=> 'คุณสามารถระบุพอร์ตที่ใช้เพื่อติดต่อกับ LDAP เซิร์ฟเวอร์ แทนที่จะใช้พอร์ตเริ่มต้น 389',
 	'LDAP_SERVER'					=> 'LDAP เซิร์ฟเวอร์ name',
 	'LDAP_SERVER_EXPLAIN'			=> 'ถ้ากำลังใช้ LDAP นี่คือ hostname หรือ IP address ของ LDAP เซิร์ฟเวอร์ คุณสามารถระบุ URL เช่น ldap://hostname:port/',
 	'LDAP_UID'						=> 'LDAP <var>uid</var>',
-	'LDAP_UID_EXPLAIN'				=> 'This is the key under which to search for a given login identity, ตัวอย่างเช่น <var>uid</var>, <var>sn</var>, etc.',
+	'LDAP_UID_EXPLAIN'				=> 'คีย์ที่ใช้ในการระบุเอกลักษณ์การล็อคอิน, ตัวอย่างเช่น <var>uid</var>, <var>sn</var>, etc.',
 	'LDAP_USER'						=> 'ผู้ใช้ LDAP<var>dn</var>',
-	'LDAP_USER_EXPLAIN'				=> 'Leave blank to use anonymous binding. If filled in phpBB uses the specified distinguished name on login attempts to find the correct user, ตัวอย่างเช่น <samp>uid=Username,ou=MyUnit,o=MyCompany,c=US</samp>. Required for Active Directory Servers.',
+	'LDAP_USER_EXPLAIN'				=> 'ปล่อยว่างไว้เพื่อใช้ anonymous binding. ถ้าหากใส่ การใช้งาน phpBB ต้องใช้ชื่อที่ระบุพิเศษในการล็อคอินเพื่อที่จะหาผู้ใช้ที่ถูกต้อง, ตัวอย่างเช่น <samp>uid=Username,ou=MyUnit,o=MyCompany,c=US</samp>. Required for Active Directory Servers.',
 	'LDAP_USER_FILTER'				=> 'การกรองผู้ใช้ LDAP',
-	'LDAP_USER_FILTER_EXPLAIN'		=> 'Optionally you can further limit the searched objects with additional filters. For example <samp>objectClass=posixGroup</samp> would result in the use of <samp>(&(uid=$username)(objectClass=posixGroup))</samp>',
+	'LDAP_USER_FILTER_EXPLAIN'		=> '(ตัวเลือก) คุณสามารถจำกัดข้อมูลที่ถูกค้นหาด้วยตัวกรองเพิ่มเติม. ตัวอย่าง <samp>objectClass=posixGroup</samp> จะให้ผลลัพธ์ในการใช้ของ <samp>(&(uid=$username)(objectClass=posixGroup))</samp>',
 ));
 
 // Server Settings
@@ -477,7 +477,7 @@ $lang = array_merge($lang, array(
 	'BROWSER_VALID'					=> 'ตรวจสอบเบราเซอร์',
 	'BROWSER_VALID_EXPLAIN'			=> 'ตั้งค่าให้มีการทำ browser validation สำหรับแต่ละ session เพื่อปรับปรุงความปลอดภัย',
 	'CHECK_DNSBL'					=> 'ตรวจสอบ IP กับ รายการของ DNS',
-	'CHECK_DNSBL_EXPLAIN'			=> 'ถ้าเลือกใช้ IP address ของผู้ใช้จะถูกตรวจสอบกับ DNSBL ดังข้างล่างนี้: <a href="http://spamcop.net">spamcop.net</a>, <a href="http://dsbl.org">dsbl.org</a> and <a href="http://www.spamhaus.org">www.spamhaus.org</a>. This lookup may take a while, depending on the เซิร์ฟเวอร์’s configuration. If slowdowns are experienced or too many false positives reported it is recommended to disable this check.',
+	'CHECK_DNSBL_EXPLAIN'			=> 'ถ้าเลือกใช้ IP address ของผู้ใช้จะถูกตรวจสอบกับ DNSBL ดังข้างล่างนี้: <a href="http://spamcop.net">spamcop.net</a>, <a href="http://dsbl.org">dsbl.org</a> and <a href="http://www.spamhaus.org">www.spamhaus.org</a>. การตรวจสอบอาจใช้เวลา, ขึ้นอยู่กับการตั้งค่าของเซิร์ฟเวอร์. หากการทำงานล่าช้าหรือมีการรายงานที่ผิดพลาด ควรปิดการทำงานของฟังชั่นนี้',
 	'CLASS_B'						=> 'A.B',
 	'CLASS_C'						=> 'A.B.C',
 	'EMAIL_CHECK_MX'				=> 'ตรวจสอบ โดเมนของอีเมล เพื่อความถูกต้องของ MX record',
@@ -486,22 +486,22 @@ $lang = array_merge($lang, array(
 	'FORCE_PASS_CHANGE_EXPLAIN'		=> 'บังคับให้ผู้ใช้เปลี่ยนรหัสผ่าน หลังจากตั้งค่า จำนวนวัน ตั้งค่าเป็น 0 เพื่อไม่ใช้พฤติกรรมนี้',
 	'FORM_TIME_MAX'					=> 'เวลาสูงสุดที่ส่งค่าจากฟอร์ม',
 	'FORM_TIME_MAX_EXPLAIN'			=> 'เวลาสูงสุดที่ส่งฟอร์ม ใช้ -1 เพื่อยกเลิกพฤติกรรมนี้ โปรดทราบว่า ฟอร์มอาจจะไม่ถูกต้องถ้า session หมดอายุ โดยที่ไม่เกี่ยวกับค่านี้',
-	'FORM_SID_GUESTS'				=> 'Tie forms to guest sessions',
-	'FORM_SID_GUESTS_EXPLAIN'		=> 'If enabled, the form token issued to guests will be session-exclusive. อาจมีปัญหาสำหรับบาง ISP.',
+	'FORM_SID_GUESTS'				=> 'ผูกค่าฟอร์มกับ guest sessions',
+	'FORM_SID_GUESTS_EXPLAIN'		=> 'ถ้าหากเปิดใช้, ค่าของฟอร์มสำหรับแขกผู้เข้าชมเว็บจะถูก session เฉพาะ. อาจมีปัญหาสำหรับบาง ISP.',
 	
 	
-	'FORWARDED_FOR_VALID'			=> 'Validate <var>X_FORWARDED_FOR</var> header',
-	'FORWARDED_FOR_VALID_EXPLAIN'	=> 'Sessions will only be continued if the sent <var>X_FORWARDED_FOR</var> header equals the one sent with the previous request. Bans will be checked against IPs in <var>X_FORWARDED_FOR</var> too.',
-	'IP_VALID'						=> 'Session IP validation',
-	'IP_VALID_EXPLAIN'				=> 'Determines how much of the users IP is used to validate a session; <samp>All</samp> compares the complete address, <samp>A.B.C</samp> the first x.x.x, <samp>A.B</samp> the first x.x, <samp>None</samp> disables checking. On IPv6 addresses <samp>A.B.C</samp> compares the first 4 blocks and <samp>A.B</samp> the first 3 blocks.',
-	'IP_LOGIN_LIMIT_MAX'			=> 'Maximum number of login attempts per IP address',
-	'IP_LOGIN_LIMIT_MAX_EXPLAIN'	=> 'The threshold of login attempts allowed from a single IP address before an anti-spambot task is triggered. Enter 0 to prevent the anti-spambot task from being triggered by IP addresses.',
-	'IP_LOGIN_LIMIT_TIME'			=> 'IP address login attempt expiration time',
-	'IP_LOGIN_LIMIT_TIME_EXPLAIN'	=> 'Login attempts expire after this period.',
-	'IP_LOGIN_LIMIT_USE_FORWARDED'	=> 'Limit login attempts by <var>X_FORWARDED_FOR</var> header',
-	'IP_LOGIN_LIMIT_USE_FORWARDED_EXPLAIN'	=> 'Instead of limiting login attempts by IP address they are limited by <var>X_FORWARDED_FOR</var> values. <br /><em><strong>Warning:</strong> Only enable this if you are operating a proxy server that sets <var>X_FORWARDED_FOR</var> to trustworthy values.</em>',
-	'MAX_LOGIN_ATTEMPTS'			=> 'Maximum number of login attempts per username',
-	'MAX_LOGIN_ATTEMPTS_EXPLAIN'	=> 'The number of login attempts allowed for a single account before the anti-spambot task is triggered. Enter 0 to prevent the anti-spambot task from being triggered for distinct user accounts.',
+	'FORWARDED_FOR_VALID'			=> 'การตรวจสอบ <var>X_FORWARDED_FOR</var> header',
+	'FORWARDED_FOR_VALID_EXPLAIN'	=> 'Sessions จะถูกดำเนินการต่อ ถ้าหากค่า <var>X_FORWARDED_FOR</var> header ที่ถูกส่งเท่ากับค่าครั้งก่อน. การแบนจะถูกตรวจสอบเทียบกับ IPs ใน <var>X_FORWARDED_FOR</var> เช่นกัน.',
+	'IP_VALID'						=> 'การตรวจสอบ IP Session',
+	'IP_VALID_EXPLAIN'				=> 'กำหนดส่วนประกอบการตรวจสอบ session ของไอพีผู้ใช้; <samp>ทั้งหมด</samp> เปรียบเทียบที่อยู่ไอพีทั้งชุด, <samp>A.B.C</samp> x.x.x 3 ชุดแรก, <samp>A.B</samp> x.x สองชุดแรก, <samp>ไม่มี</samp> ปิดการตรวจสอบ. ในรูปแบบของที่อยู่ IPv6 <samp>A.B.C</samp> เปรียบเทียบ 4 ชุดแรก และ <samp>A.B</samp> สำหรับ 3 ชุดแรก.',
+	'IP_LOGIN_LIMIT_MAX'			=> 'จำกัดจำนวนครั้งล็อคอินต่อหนึ่งไอพี ในกรณีที่การล็อคอินไม่ถูกต้อง',
+	'IP_LOGIN_LIMIT_MAX_EXPLAIN'	=> 'จำนวนครั้งที่อนุญาตให้ล็อคอินต่อหนึ่งไอพี ก่อนที่ระบบป้องกันสแปมจะทำงาน ใส่ 0 เพื่อปิดระบบป้องกันสแปม.',
+	'IP_LOGIN_LIMIT_TIME'			=> 'ตั้งเวลาล็อคไอพีไม่ให้ทำการล็อคอิน หลังจากล็อคอินล้มเเหลว',
+	'IP_LOGIN_LIMIT_TIME_EXPLAIN'	=> 'การล็อคจะสิ้นสุดลงหลังจากระยะเวลานี้',
+	'IP_LOGIN_LIMIT_USE_FORWARDED'	=> 'จำกัดจำนวนการล็อคอินโดย <var>X_FORWARDED_FOR</var> header',
+	'IP_LOGIN_LIMIT_USE_FORWARDED_EXPLAIN'	=> 'แทนที่จะจำกัดจำนวนครั้งของการล็อคอินที่ผิดพลาดโดย IP address ผู้ใช้จะถูกจำกัดโดยค่า <var>X_FORWARDED_FOR</var> <br /><em><strong>คำเตือน:</strong> เปิดใช้งานฟังชั่นนี้ต่อเมื่อคุณใช้งาน proxy server ที่ตั้งค่าให้ <var>X_FORWARDED_FOR</var> เป็นค่าที่น่าเชื่อถือ.</em>',
+	'MAX_LOGIN_ATTEMPTS'			=> 'จำนวนครั้งที่อนุญาตให้ล็อคอินต่อหนึ่งไอดีผู้ใช้ ในกรณีที่การล็อคอินไม่ถูกต้อง',
+	'MAX_LOGIN_ATTEMPTS_EXPLAIN'	=> 'จำนวนครั้งที่อนุญาตให้ล็อคอินต่อหนึ่งไอดีผู้ใช้ ก่อนที่ระบบป้องกันสแปมจะทำงาน ใส่ 0 เพื่อปิดระบบป้องกันสแปม.',
 	
 	
 	'NO_IP_VALIDATION'				=> 'ไม่มี',
@@ -566,17 +566,17 @@ $lang = array_merge($lang, array(
 	'ACP_JABBER_SETTINGS_EXPLAIN'	=> 'คุณสามารถเลือกใช้และควบคุมการใช้ Jabber สำหรับ instant messaging และการแจ้งบอร์ด Jabber เป็น open source โปรโตคอลและทุกคนมีสิทธิ์ใช้ บาง Jabber เซิร์ฟเวอร์ ประกอบด้วย gateway ที่อนุญาตให้คุณติดต่อผู้ใช้ในเครือข่ายอื่น มีแค่บางเซิร์ฟเวอร์เท่านั้นที่อนุญาตการขนส่งทั้งหมด การเปลี่ยนโปรโตคอลอาจทำให้การขนส่งใช้การไม่ได้ โปรดตรวจสอบข้อมูลให้แน่ใจในการกรอกรายละเอียดบัญชีผู้ใช้ที่ลงทะเบียนแล้ว - phpBB จะใช้รายละเอียดที่คุณกรอก',
 
 	'JAB_ENABLE'				=> 'เปิดใช้งาน Jabber',
-	'JAB_ENABLE_EXPLAIN'		=> 'Enables use of Jabber messaging and notifications.',
+	'JAB_ENABLE_EXPLAIN'		=> 'เปิดใช้งานการส่งข้อความและการแจ้งเตือนของ Jabber.',
 	'JAB_GTALK_NOTE'			=> 'โปรดทราบ ไม่สามารถใช้ GTalk ได้ เพราะว่าไม่พบ <samp>dns_get_record</samp> ฟังก์ชัน ฟังก์ชันนี้ไม่มีใน PHP4 และไม่มีการทำบน Windows และก็ไม่สามารถใช้ได้บน BSD รวมทั้ง Mac OS',
-	'JAB_PACKAGE_SIZE'			=> 'Jabber package size',
+	'JAB_PACKAGE_SIZE'			=> 'ขนาด Jabber package',
 	'JAB_PACKAGE_SIZE_EXPLAIN'	=> 'ค่านี้เป็นจำนวนข้อความที่ถูกส่งไปใน 1 package ถ้าตั้งค่าเป็น 0 ข้อความจะถูกส่งทันทีโดยไม่มีการรอจัดลำดับการส่ง',
 	'JAB_PASSWORD'				=> 'รหัสผ่านของ Jabber',
 	'JAB_PASSWORD_EXPLAIN'		=> '<em><strong>เตือน:</strong>รหัสผ่านจะถูกเก็บเป็นข้อความธรรมดาไว้ในฐานข้อมูล  จะสามารถเห็นได้จากฐานข้อมูลของท่านหรือดูได้จากหน้าตั้งค่า.</em>',
 	
-	'JAB_PORT'					=> 'Jabber พอร์ต',
+	'JAB_PORT'					=> 'พอร์ต Jabber',
 	'JAB_PORT_EXPLAIN'			=> 'ปล่อยให้เป็นค่าว่าง นอกเสียจากคุณทราบว่า พอร์ตที่ใช้ ไม่ใช่ 5222',
-	'JAB_SERVER'				=> 'Jabber server',
-	'JAB_SERVER_EXPLAIN'		=> 'See %sjabber.org%s for a list of servers.',
+	'JAB_SERVER'				=> 'เซิฟเวอร์ Jabber',
+	'JAB_SERVER_EXPLAIN'		=> 'คลิกดูรายการเซิฟเวอร์ที่ %sjabber.org%s',
 	'JAB_SETTINGS_CHANGED'		=> 'การเปลี่ยนการตั้งค่า Jabber สำเร็จ',
 	'JAB_USE_SSL'				=> 'ใช้ SSL สำหรับการเชื่อมต่อ',
 	'JAB_USE_SSL_EXPLAIN'		=> 'ถ้าใช้ค่านี้ จะใช้การติดต่อแบบปลอดภัย Jabber จะถูกแก้ไขเป็น 5223 ถ้าพอร์ต 5222 ถูกระบุ',
@@ -608,7 +608,7 @@ $lang = array_merge($lang, array(
 	'WPM_SUBJECT_EXPLAIN'		=> 'หัวเรื่องของข้อความที่จะถูกส่ง',
 	'WPM_MESSAGE'				=> 'ข้อความ',
 	'WPM_MESSAGE_EXPLAIN'		=> 'เนื้อหาข้อความที่จะถูกส่งไป',
-	'WPM_VARS'					=> 'Dyanamic Variables',
+	'WPM_VARS'					=> 'ตัวแปรไดนามิก',
 	'WPM_VARS_EXPLAIN'			=> 'ตัวแปรที่จะแสดงข้อมูลจริงของผู้ลงทะเบียน',
 	'WPM_VARIABLES'				=> '<strong>{USERNAME}</strong>: ชื่อผู้ใช้<br /><strong>{USER_IP}</strong>: สมาชิก\' ไอพี<br /><strong>{USER_REGDATE}</strong>: วันที่ลงทะเบียน.<br /><strong>{USER_EMAIL}</strong>: User\'s email.<br /><strong>{SITE_NAME}</strong>: Your site\'s name.<br /><strong>{SITE_DESC}</strong>: Your site\'s description.',
 
