@@ -1,7 +1,7 @@
 <?php
 /** 
-* ภาษาไทย เวอร์ชั่น 1.2.3 
-* 23/11/2553  
+* ภาษาไทย เวอร์ชั่น 1.2.6
+* 27/8/2555  
 * ไฟล์ภาษาไทยสำหรับ PHPBB3 โดย www.mindphp.com และ www.phpbbthailand.com
 *
 */ 
@@ -112,8 +112,8 @@ $lang = array_merge($lang, array(
 	'ACP_ICONS'					=> 'ไอคอนกระทู้',
 	'ACP_ICONS_SMILIES'			=> 'หัวข้อ ไอคอน/รูปแสดงอารมณ์',
 	'ACP_IMAGESETS'				=> 'กลุ่มรูปภาพ',
-	'ACP_INACTIVE_USERS'		=> 'ผู้ใช้ที่ไม่ active',
-	'ACP_INDEX'					=> 'ACP index',
+	'ACP_INACTIVE_USERS'		=> 'ผู้ใช้ที่ไม่ได้ใช้งาน',
+	'ACP_INDEX'					=> 'หน้าแรก ACP',
 	
 	'ACP_JABBER_SETTINGS'		=> 'ตั้งค่า Jabber',
 	
@@ -127,8 +127,8 @@ $lang = array_merge($lang, array(
 	'ACP_MANAGE_FORUMS'			=> 'จัดการเว็บบอร์ด',
 	'ACP_MANAGE_RANKS'			=> 'จัดการ การจัดอันดับ',
 	'ACP_MANAGE_REASONS'		=> 'จัดการ รายงาน/เหตุผลที่ไม่รับ',
-	'ACP_MANAGE_USERS'			=> 'จัดการ ผู้ใช้',
-	'ACP_MASS_EMAIL'			=> 'แมสส์เมล',
+	'ACP_MANAGE_USERS'			=> 'จัดการผู้ใช้',
+	'ACP_MASS_EMAIL'			=> 'ส่งอีเมล์ปริมาณมาก',
 	'ACP_MESSAGES'				=> 'ข้อความ',
 	'ACP_MESSAGE_SETTINGS'		=> 'ตั้งค่าข้อความส่วนตัว',
 	'ACP_MODULE_MANAGEMENT'		=> 'จัดการโมดูล',
@@ -183,7 +183,7 @@ $lang = array_merge($lang, array(
 	
 	'ACP_UPDATE'					=> 'กำลังอัพเดด',
 	'ACP_USERS_FORUM_PERMISSIONS'	=> 'การอนุญาตของผู้ใช้บอร์ด',
-	'ACP_USERS_LOGS'				=> 'User logs',
+	'ACP_USERS_LOGS'				=> 'Logs ผู้ใช้',
 	'ACP_USERS_PERMISSIONS'			=> 'การอนุญาตของผู้ใช้',
 	'ACP_USER_ATTACH'				=> 'ไฟล์แนบ',
 	'ACP_USER_AVATAR'				=> 'ภาพประจำตัว',
@@ -231,6 +231,7 @@ $lang = array_merge($lang, array(
 	'DEACTIVATE'				=> 'ทำให้ใช้การไม่ได้',
 	'DIRECTORY_DOES_NOT_EXIST'	=> 'เส้นทางที่ระบุ “%s” ไม่มีอยู่จริง.',
 	'DIRECTORY_NOT_DIR'			=> 'เส้นทางที่ระบุ “%s” ไม่ใช่ไดเรกทอรี่.',
+
 	'DIRECTORY_NOT_WRITABLE'	=> 'เส้นทางที่ระบุ “%s” ไม่สามารถเขียนทับได้.',
 	'DISABLE'					=> 'ทำให้ใช้ไม่ได้',
 	'DOWNLOAD'					=> 'ดาวน์โหลด',
@@ -289,17 +290,17 @@ $lang = array_merge($lang, array(
 	'SELECT_ANONYMOUS'		=> 'เลือกผู้ใช้ที่ไม่เปิดเผย',
 	'SELECT_OPTION'			=> 'เลือกตัวเลือก',
 
-	'UCP'					=> 'User Control Panel',
+	'UCP'					=> 'ส่วนจัดการผู้ใช้',
 	'USERNAMES_EXPLAIN'		=> 'ใส่ชื่อผู้ใช้ คนละบรรทัด บรรทัดละหนึ่งคน.',
-	'USER_CONTROL_PANEL'	=> 'User Control Panel',
+	'USER_CONTROL_PANEL'	=> 'ส่วนจัดการผู้ใช้',
 
 	'WARNING'				=> 'การเตือน',
 
-	'SETTING_TOO_LOW'		=> 'The provided value for the setting “%1$s” is too low. The minimum acceptable value is %2$d.',
-	'SETTING_TOO_BIG'		=> 'The provided value for the setting “%1$s” is too high. The maximum acceptable value is %2$d.',
-	'SETTING_TOO_LONG'		=> 'The provided value for the setting “%1$s” is too long. The maximum acceptable length is %2$d.',
-	'SETTING_TOO_SHORT'		=> 'The provided value for the setting “%1$s” is too short. The minimum acceptable length is %2$d.',
-	'SHOW_ALL_OPERATIONS'	=> 'Show all operations',
+	'SETTING_TOO_LOW'		=> 'ค่าที่ตั้งสำหรับ “%1$s” นั้นต่ำเกินไป. ค่าที่ต่ำที่สุดที่ยอมรับได้คือ %2$d.',
+	'SETTING_TOO_BIG'		=> 'ค่าที่ตั้งสำหรับ “%1$s” นั้นสูงเกินไป. ค่าที่สูงที่สุดที่รับได้คือ %2$d.',
+	'SETTING_TOO_LONG'		=> 'ค่าที่ตั้งสำหรับ “%1$s” นั้นยาวเกินไป. ความยาวสูงสุดที่รับได้คือ %2$d.',
+	'SETTING_TOO_SHORT'		=> 'ค่าที่ตั้งสำหรับ “%1$s” นั้นสั้นเกินไป. ความสั้นต่ำสุดที่รับได้คือ %2$d.',
+	'SHOW_ALL_OPERATIONS'	=> 'แสดงการดำเนินการทั้งหมด',
 	
 ));
 
@@ -324,13 +325,13 @@ $lang = array_merge($lang, array(
 
 	'SORT_IP'		=> 'ไอพี',
 	'SORT_DATE'		=> 'วันที่',
-	'SORT_ACTION'	=> 'Log action',
+	'SORT_ACTION'	=> 'บันทึกการกระทำ',
 ));
 
 // Index page
 $lang = array_merge($lang, array(
 	'ADMIN_INTRO'				=> 'ขอบคุณที่เลือกใช้ phpBB เป็นเวบบอร์ด หน้าจอนี้จะแสดงข้อมูลสถิติต่างๆของบอร์ดโดยสรุป ลิงค์ทางด้านซ้ายจะช่วยให้คุณควบคุมทุกแง่มุมของบอร์ด แต่ละหน้าจะมีวิธีใช้เครื่องมือต่างๆให้',
-	'ADMIN_LOG'					=> 'Logged administrator actions',
+	'ADMIN_LOG'					=> 'บันทึกการกระทำของผู้ดูแลระบบ',
 	'ADMIN_LOG_INDEX_EXPLAIN'	=> 'ข้อความนี้สรุปกิจกรรมล่าสุด 5 ครั้งที่กระทำโดยผู้ดูแลระบบ ข้อความสำเนาทั้งหมดสามารถดูได้จากเมนูที่จัดไว้ให้แล้วหรือไปตามลิงค์ข้างล่างนี้',
 	'AVATAR_DIR_SIZE'			=> 'ขนาดไดเรกทอรีของภาพประจำตัว',
 
@@ -345,9 +346,9 @@ $lang = array_merge($lang, array(
 	'ERROR_MBSTRING_FUNC_OVERLOAD_EXPLAIN'			=> '<var>mbstring.func_overload</var> จำเป็นต้องเป็นค่า 0 หรือ 4. สามารถเช็คค่าที่ตั้งไว้ตอนนี้ได้ที่หน้า  <samp>ข้อมูล PHP</samp>.',
 	'ERROR_MBSTRING_ENCODING_TRANSLATION'			=> 'Transparent character encoding ถูกกำหนดไว้ไม่ถูกต้อง',
 	'ERROR_MBSTRING_ENCODING_TRANSLATION_EXPLAIN'	=> '<var>mbstring.encoding_translation</var> จำเป็นต้องตั้งเป็น 0. สามารถเช็คค่าที่ตั้งไว้ตอนนี้ได้ที่หน้า  <samp>ข้อมูล PHP</samp>.',
-	'ERROR_MBSTRING_HTTP_INPUT'						=> 'HTTP input character conversion is improperly configured',
+	'ERROR_MBSTRING_HTTP_INPUT'						=> 'HTTP input character conversion ถูกตั้งค่าไม่เหมาะสม',
 	'ERROR_MBSTRING_HTTP_INPUT_EXPLAIN'				=> '<var>mbstring.http_input</var> ต้องถูกกำหนดหเป็น <samp>pass</samp>. สามารถเช็คค่าที่ตั้งไว้ตอนนี้ได้ที่หน้า  <samp>ข้อมูล PHP</samp>.',
-	'ERROR_MBSTRING_HTTP_OUTPUT'					=> 'HTTP output character conversion is improperly configured',
+	'ERROR_MBSTRING_HTTP_OUTPUT'					=> 'HTTP output character conversion ถูกตั้งค่าไม่เหมาะสม',
 	'ERROR_MBSTRING_HTTP_OUTPUT_EXPLAIN'			=> '<var>mbstring.http_output</var> ต้องถูกกำหนดหเป็น <samp>pass</samp>. สามารถเช็คค่าที่ตั้งไว้ตอนนี้ได้ที่หน้า  <samp>ข้อมูล PHP</samp>.',
 
 
@@ -363,7 +364,7 @@ $lang = array_merge($lang, array(
 	'NUMBER_USERS'		=> 'จำนวนของผู้ใช้',
 	'NUMBER_ORPHAN'		=> 'ไฟล์แนบที่ไม่มีเจ้าของ',
 
-	'PHP_VERSION_OLD'	=> 'The version of PHP on this server will no longer be supported by future versions of phpBB. %รายละเอียด%s',
+	'PHP_VERSION_OLD'	=> 'เวอร์ชั่นของ PHP บนเซิฟเวอร์นี้ จะไม่รองรับการทำของของ phpBB เวอร์ชั่นถัดไป. %sรายละเอียด%s ',
 
 	'POSTS_PER_DAY'		=> 'จำนวนการโพสต์ต่อวัน',
 
@@ -400,20 +401,20 @@ $lang = array_merge($lang, array(
 
 	'VALUE'					=> 'ค่า',
 
-	'VERSIONCHECK_FAIL'			=> 'Failed to obtain latest version information.',
-	'VERSIONCHECK_FORCE_UPDATE'	=> 'Re-Check version',
+	'VERSIONCHECK_FAIL'			=> 'การตรวจสอบข้อมูลเวอชั่นล้มเหลว',
+	'VERSIONCHECK_FORCE_UPDATE'	=> 'ตรวจสอบเวอชั่นอีกครั้ง',
 
 	
-	'VIEW_ADMIN_LOG'		=> 'เรียกดู administrator log',
-	'VIEW_INACTIVE_USERS'	=> 'เรียกดู ผู้ใช้ที่ไม่มีการเข้าใช้',
+	'VIEW_ADMIN_LOG'		=> 'เรียกดูบันทึกผู้ดูแลระบบ',
+	'VIEW_INACTIVE_USERS'	=> 'เรียกดู ผู้ใช้ที่ไม่ได้ใช้งาน',
 
-	'WELCOME_PHPBB'			=> 'ยินดีต้อนรับสู่ ศูนย์ดำเนินการระบบ',
+	'WELCOME_PHPBB'			=> 'ยินดีต้อนรับสู่ ศูนย์ควบคุมระบบ',
 	'WRITABLE_CONFIG'		=> 'ไฟล์ config (config.php) ยังสามารถเขียนทับได้. ควรเปลี่ยน permissions เป็น 640 หรือ 644 (ตัวอย่างการเปลี่ยน permissions : <a href="http://en.wikipedia.org/wiki/Chmod" rel="external">chmod</a> 640 config.php).',	
 ));
 
 // Inactive Users
 $lang = array_merge($lang, array(
-	'INACTIVE_DATE'					=> 'Inactive date',
+	'INACTIVE_DATE'					=> 'วันที่ไม่มีการใช้งาน',
 	'INACTIVE_REASON'				=> 'เหตุผล',
 	'INACTIVE_REASON_MANUAL'		=> 'บัญชีที่ผู้ดูแลระบบทำให้ใช้ไม่ได้',
 	'INACTIVE_REASON_PROFILE'		=> 'รายละเอียดข้อมูลโดยรวมเปลี่ยนแปลงแล้ว',
@@ -422,7 +423,7 @@ $lang = array_merge($lang, array(
 	'INACTIVE_REASON_UNKNOWN'		=> 'ไม่ทราบ',
 	'INACTIVE_USERS'				=> 'ผู้ใช้ที่ไม่มีการเข้าใช้แล้ว',
 	'INACTIVE_USERS_EXPLAIN'		=> 'ข้อความนี้แสดงผู้ใช้ที่มีการลงทะเบียนแต่ไม่มีการเข้าใช้ คุณสามารถ ทำให้บัญชีผู้ใช้ใช้งานได้, ลบบัญชีผู้ใช้หรือเตือน(โดยส่ง อีเมล) หากคุณต้องการ',
-	'INACTIVE_USERS_EXPLAIN_INDEX'	=> 'ข้อความนี้แสดงผู้ใช้ 10 คนล่าสุดที่ลงทะเบียนแต่ไม่มีการเข้าใช้ รายการทั้งหมดของผู้ใช้ที่ไม่มีการเข้าใช้สามารถเรียกดูได้จากเมนูที่จัดไว้ให้แล้ว หรือ โดยการไปตามลิงค์ข้างล่างนี้ เพื่อที่คุณจะได้ทำการ ทำให้บัญชีผู้ใช้ใช้งานได้, ลบบัญชีผู้ใช้หรือเตือน(โดยส่ง อีเมล) หากคุณต้องการ',
+	'INACTIVE_USERS_EXPLAIN_INDEX'	=> 'ข้อความนี้แสดงผู้ใช้ 10 คนล่าสุดที่ลงทะเบียนแต่ไม่มีการเข้าใช้ รายการทั้งหมดของผู้ใช้ที่ไม่มีการเข้าใช้สามารถเรียกดูได้จากเมนูที่จัดไว้ให้แล้ว หรือ โดยการไปตามลิงค์ข้างล่างนี้ เพื่อที่คุณจะได้ทำให้บัญชีผู้ใช้ใช้งานได้, ลบบัญชีผู้ใช้หรือเตือน(โดยส่ง อีเมล) หากคุณต้องการ',
 
 	'NO_INACTIVE_USERS'	=> 'ไม่มีผู้ใช้ที่ไม่มีการใช้งาน',
 
@@ -431,8 +432,8 @@ $lang = array_merge($lang, array(
 	'SORT_REASON'		=> 'เหตุผล',
 	'SORT_REG_DATE'		=> 'วันที่ลงทะเบียน',
 
-	'SORT_LAST_REMINDER'=> 'Last reminded',
-	'SORT_REMINDER'		=> 'Reminder sent',
+	'SORT_LAST_REMINDER'=> 'เตือนครั้งสุดท้าย',
+	'SORT_REMINDER'		=> 'การแจ้งเตือนถูกส่ง',
 
 	'USER_IS_INACTIVE'		=> 'ผู้ใช้นี้ไม่มีการใช้งาน',
 ));
@@ -612,10 +613,10 @@ $lang = array_merge($lang, array(
 */	
 	'LOG_USERS_ADDED'		=> '<strong>เพิ่มสมาชิกใหม่เข้ากลุ่มผู้ใช้</strong> %1$s<br />? %2$s',
 
-	'LOG_USERS_APPROVED'	=> '<strong>Users approved in usergroup</strong> %1$s<br />» %2$s',
-	'LOG_USERS_PENDING'		=> '<strong>Users requested to join group “%1$s” and need to be approved</strong><br />» %2$s',
+	'LOG_USERS_APPROVED'	=> '<strong>ผู้ใช้ได้รับอนุมัติในกลุ่มผู้ใช้</strong> %1$s<br />» %2$s',
+	'LOG_USERS_PENDING'		=> '<strong>ผู้ใช้ร้องขอที่จะเข้ากลุ่ม “%1$s” และรอการอนุมัติ</strong><br />» %2$s',
 
-	'LOG_IMAGE_GENERATION_ERROR'	=> '<strong>Error while creating image</strong><br />» Error in %1$s on line %2$s: %3$s',
+	'LOG_IMAGE_GENERATION_ERROR'	=> '<strong>ผิดพลาดขณะกำลังสร้างรูป</strong><br />» ผิดพลาดใน %1$s บนบรรทัดที่ %2$s: %3$s',
 
 	'LOG_IMAGESET_ADD_DB'			=> '<strong>เพิ่มกลุ่มรูปภาพใหม่ในฐานข้อมูล</strong><br />? %s',
 	'LOG_IMAGESET_ADD_FS'			=> '<strong>เพิ่มกลุ่มรูปภาพใหม่บนระบบไฟล์</strong><br />? %s',
@@ -624,8 +625,8 @@ $lang = array_merge($lang, array(
 	'LOG_IMAGESET_EDIT'				=> '<strong>แก้ไขกลุ่มรูปภาพ</strong><br />? %s',
 	'LOG_IMAGESET_EXPORT'			=> '<strong>ส่งกลุ่มรูปภาพออก</strong><br />? %s',
 	'LOG_IMAGESET_LANG_MISSING'		=> '<strong>กลุ่มรูปภาพ misses “%2$s” localisation</strong><br />? %1$s',
-	'LOG_IMAGESET_LANG_REFRESHED'	=> '<strong>Refreshed “%2$s” localisation ของกลุ่มรูปภาพ</strong><br />? %1$s',
-	'LOG_IMAGESET_REFRESHED'		=> '<strong>Refreshed กลุ่มรูปภาพ</strong><br />? %s',
+	'LOG_IMAGESET_LANG_REFRESHED'	=> '<strong>รีเฟรช “%2$s” localisation ของกลุ่มรูปภาพแล้ว</strong><br />? %1$s',
+	'LOG_IMAGESET_REFRESHED'		=> '<strong>รีเฟรชกลุ่มรูปภาพแล้ว</strong><br />? %s',
 
 	'LOG_INACTIVE_ACTIVATE'	=> '<strong>ทำให้บัญชีผู้ใช้ที่ไม่มีการเข้าใช้กลับมาใช้งานได้</strong><br />? %s',
 	'LOG_INACTIVE_DELETE'	=> '<strong>ลบผู้ใช้ที่ไม่มีการเข้าใช้</strong><br />? %s',
@@ -633,16 +634,16 @@ $lang = array_merge($lang, array(
 	'LOG_INSTALL_CONVERTED'	=> '<strong>แปลงจาก %1$s เป็น phpBB %2$s</strong>',
 	'LOG_INSTALL_INSTALLED'	=> '<strong>ติดตั้ง phpBB %s</strong>',
 
-	'LOG_IP_BROWSER_FORWARDED_CHECK'	=> '<strong>Session IP/browser/X_FORWARDED_FOR check failed</strong><br />?ผู้ใช้ IP “<em>%1$s</em>” checked against session IP “<em>%2$s</em>”, user browser string “<em>%3$s</em>” checked against session browser string “<em>%4$s</em>” และ user X_FORWARDED_FOR string “<em>%5$s</em>” checked against session X_FORWARDED_FOR string “<em>%6$s</em>”.',
+	'LOG_IP_BROWSER_FORWARDED_CHECK'	=> '<strong>การตรวจสอบ Session IP/browser/X_FORWARDED_FOR ล้มเหลว</strong><br />?ผู้ใช้ IP “<em>%1$s</em>” ตรวจสอบเทียบกับ session IP “<em>%2$s</em>”, browser string ผู้ใช้ “<em>%3$s</em>” ตรวจสอบเทียบกับ session browser string “<em>%4$s</em>” และ user X_FORWARDED_FOR string “<em>%5$s</em>” ตรวจสอบเทียบกับ session X_FORWARDED_FOR string “<em>%6$s</em>”.',
 
-	'LOG_JAB_CHANGED'			=> '<strong>Jabber account changed</strong>',
-	'LOG_JAB_PASSCHG'			=> '<strong>Jabber password changed</strong>',
-	'LOG_JAB_REGISTER'			=> '<strong>Jabber account registered</strong>',
+	'LOG_JAB_CHANGED'			=> '<strong>Jabber account เปลี่ยนแล้ว</strong>',
+	'LOG_JAB_PASSCHG'			=> '<strong>Jabber password เปลี่ยนแล้ว</strong>',
+	'LOG_JAB_REGISTER'			=> '<strong>ลงทะเบียน Jabber account แล้ว</strong>',
 	'LOG_JAB_SETTINGS_CHANGED'	=> '<strong>Jabber ตั้งค่า changed</strong>',
 
-	'LOG_LANGUAGE_PACK_DELETED'		=> '<strong>ลบ language pack</strong><br />? %s',
-	'LOG_LANGUAGE_PACK_INSTALLED'	=> '<strong>ติดตั้ง language pack</strong><br />? %s',
-	'LOG_LANGUAGE_PACK_UPDATED'		=> '<strong>อัพเดท language pack details</strong><br />? %s',
+	'LOG_LANGUAGE_PACK_DELETED'		=> '<strong>ลบชุดภาษา</strong><br />? %s',
+	'LOG_LANGUAGE_PACK_INSTALLED'	=> '<strong>ติดตั้งชุดภาษา</strong><br />? %s',
+	'LOG_LANGUAGE_PACK_UPDATED'		=> '<strong>อัพเดทรายละเอียดของชุดภาษา</strong><br />? %s',
 	'LOG_LANGUAGE_FILE_REPLACED'	=> '<strong>แทนที่ไฟล์ภาษา</strong><br />? %s',
 	'LOG_LANGUAGE_FILE_SUBMITTED'	=> '<strong>ส่งไฟล์ภาษาและ วางไว้ในโฟลเดอร์</strong><br />? %s',
 
@@ -685,7 +686,7 @@ $lang = array_merge($lang, array(
 
 	'LOG_PURGE_CACHE'			=> '<strong>ลบ cache</strong>',
 
-	'LOG_PURGE_SESSIONS'		=> '<strong>Purged sessions</strong>',
+	'LOG_PURGE_SESSIONS'		=> '<strong>sessions ถูกกำจัด</strong>',
 
 	'LOG_RANK_ADDED'		=> '<strong>เพิ่มอันดับใหม่</strong><br />? %s',
 	'LOG_RANK_REMOVED'		=> '<strong>ลบอันดับ</strong><br />? %s',
@@ -694,7 +695,7 @@ $lang = array_merge($lang, array(
 	'LOG_REASON_ADDED'		=> '<strong>เพิ่มเหตุผล report/denial</strong><br />? %s',
 	'LOG_REASON_REMOVED'	=> '<strong>ลบเหตุผล report/denial</strong><br />? %s',
 	'LOG_REASON_UPDATED'	=> '<strong>อัพเดทเหตุผล report/denial</strong><br />? %s',
-	'LOG_REFERER_INVALID'		=> '<strong>แหล่งที่มาไม่ถูกต้อง</strong><br />»Referer was “<em>%1$s</em>”. The request was rejected and the session killed.',
+	'LOG_REFERER_INVALID'		=> '<strong>แหล่งที่มาไม่ถูกต้อง</strong><br />»ผู้อ้างถึงคือ “<em>%1$s</em>”. คำร้องขอถูกยกเลิกและ session ถูกทำลาย.',
 	'LOG_RESET_DATE'			=> '<strong>ตั้งวันที่เริ่มใช้บอร์ดใหม่</strong>',
 	'LOG_RESET_ONLINE'			=> '<strong>ตั้งค่าผู้ใช้ที่ออนไลน์มากที่สุดใหม่</strong>',
 	'LOG_RESYNC_POSTCOUNTS'		=> '<strong>ทำการนับโพสต์ใหม่</strong>',
@@ -730,14 +731,14 @@ $lang = array_merge($lang, array(
 	'LOG_UPDATE_PHPBB'		=> '<strong>อัพเดท phpBB จาก เวอร์ชัน %1$sไปเวอร์ชัน %2$s</strong>',
 
 	'LOG_USER_ACTIVE'		=> '<strong>ผู้ใช้ที่ใช้งานได้</strong><br />? %s',
-	'LOG_USER_BAN_USER'		=> '<strong>แบนผู้ใช้ผ่านทาง user management</strong> ด้วยเหตุผล “<em>%1$s</em>”<br />? %2$s',
-	'LOG_USER_BAN_IP'		=> '<strong>แบน IP ผ่านทาง user management</strong> ด้วยเหตุผล “<em>%1$s</em>”<br />? %2$s',
-	'LOG_USER_BAN_EMAIL'	=> '<strong>แบน อีเมล ผ่านทาง user management</strong> ด้วยเหตุผล “<em>%1$s</em>”<br />? %2$s',
+	'LOG_USER_BAN_USER'		=> '<strong>แบนผู้ใช้ผ่านทาง ระบบจัดการผู้ใช้</strong> ด้วยเหตุผล “<em>%1$s</em>”<br />? %2$s',
+	'LOG_USER_BAN_IP'		=> '<strong>แบน IP ผ่านทาง ระบบจัดการผู้ใช้</strong> ด้วยเหตุผล “<em>%1$s</em>”<br />? %2$s',
+	'LOG_USER_BAN_EMAIL'	=> '<strong>แบน อีเมล ผ่านทาง ระบบจัดการผู้ใช้</strong> ด้วยเหตุผล “<em>%1$s</em>”<br />? %2$s',
 	'LOG_USER_DELETED'		=> '<strong>ลบผู้ใช้</strong><br />» %s',
 	'LOG_USER_DEL_ATTACH'	=> '<strong>ลบทุกไฟล์แนบที่เป็นของผู้ใช้</strong><br />» %s',
 	'LOG_USER_DEL_AVATAR'	=> '<strong>ลบภาพประจำตัวของผู้ใช้</strong><br />» %s',
 
-	'LOG_USER_DEL_OUTBOX'	=> '<strong>Emptied user outbox</strong><br />» %s',
+	'LOG_USER_DEL_OUTBOX'	=> '<strong>ทำความสะอาดกล่องข้อความออกของผู้ใช้</strong><br />» %s',
 	
 	'LOG_USER_DEL_POSTS'	=> '<strong>ลบทุกโพสต์ที่เป็นของผู้ใช้</strong><br />» %s',
 	'LOG_USER_DEL_SIG'		=> '<strong>ลบลายเซ็นต์ของผู้ใช้</strong><br />» %s',
@@ -745,9 +746,9 @@ $lang = array_merge($lang, array(
 	'LOG_USER_MOVE_POSTS'	=> '<strong>ย้ายโพสต์ของผู้ใช้</strong><br />»โพสต์โดย “%1$s”ไปที่ forum “%2$s”',
 	'LOG_USER_NEW_PASSWORD'	=> '<strong>เปลี่ยน password ของผู้ใช้</strong><br />» %s',
 	
-	'LOG_USER_REACTIVATE'	=> '<strong>Forced user account reactivation</strong><br />» %s',
+	'LOG_USER_REACTIVATE'	=> '<strong>บังคับให้บัญชีผู้ใช้ reactivate</strong><br />» %s',
 
-	'LOG_USER_REMOVED_NR'	=> '<strong>Removed newly registered flag from user</strong><br />» %s',	
+	'LOG_USER_REMOVED_NR'	=> '<strong>ลบธงการลงทะเบียนใหม่ออกจากผู้ใช้</strong><br />» %s',	
 	
 	'LOG_USER_UPDATE_EMAIL'	=> '<strong>ผู้ใช้ “%1$s” เปลี่ยน อีเมล</strong><br />? จาก “%2$s” เป็น “%3$s”',
 	'LOG_USER_UPDATE_NAME'	=> '<strong>เปลี่ยนชื่อผู้ใช้</strong><br />? จาก “%1$s” เป็น “%2$s”',
@@ -761,7 +762,7 @@ $lang = array_merge($lang, array(
 	'LOG_USER_INACTIVE_USER'	=> '<strong>บัญชีผู้ใช้ที่ไม่สามารถใช้งานได้</strong>',
 	'LOG_USER_LOCK'				=> '<strong>ผู้ใช้ล็อกกระทู้ที่เป็นเจ้าของ</strong><br />? %s',
 	'LOG_USER_MOVE_POSTS_USER'	=> '<strong>ย้ายโพสต์ทั้งหมดไปที่ forum</strong>? %s',
-	'LOG_USER_REACTIVATE_USER'	=> '<strong>Forced user account reactivation</strong>',
+	'LOG_USER_REACTIVATE_USER'	=> '<strong>บังคับให้บัญชีผู้ใช้ reactivate</strong>',
 	'LOG_USER_UNLOCK'			=> '<strong>ผู้ใช้ปลดล็อกกระทู้ที่เป็นเจ้าของ</strong><br />? %s',
 	'LOG_USER_WARNING'			=> '<strong>เพิ่มการเตือนผู้ใช้</strong><br />? %s',
 	'LOG_USER_WARNING_BODY'		=> '<strong>คำเตือนต่อไปนี้ถูกส่งไปที่ผู้ใช้</strong><br />? %s',
@@ -772,9 +773,9 @@ $lang = array_merge($lang, array(
 	'LOG_USER_GROUP_JOIN_PENDING'	=> '<strong>ผู้ใช้เข้าร่วมกลุ่มและต้องได้รับการอนุมัติ</strong><br />? %s',
 	'LOG_USER_GROUP_RESIGN'			=> '<strong>ผู้ใช้ลาออกจากกลุ่ม</strong><br />» %s',
 
-	'LOG_WARNING_DELETED'		=> '<strong>Deleted user warning</strong><br />» %s',
-	'LOG_WARNINGS_DELETED'		=> '<strong>Deleted %2$s user warnings</strong><br />» %1$s', // Example: '<strong>Deleted 2 user warnings</strong><br />» username'
-	'LOG_WARNINGS_DELETED_ALL'	=> '<strong>Deleted all user warnings</strong><br />» %s',
+	'LOG_WARNING_DELETED'		=> '<strong>ลบคำเตือนของผู้ใช้</strong><br />» %s',
+	'LOG_WARNINGS_DELETED'		=> '<strong>ลบ %2$s คำเตือนของผู้ใช้</strong><br />» %1$s', // Example: '<strong>Deleted 2 user warnings</strong><br />» username'
+	'LOG_WARNINGS_DELETED_ALL'	=> '<strong>ลบคำเตือนของผู้ใช้ทุกคน</strong><br />» %s',
 
 	'LOG_WORD_ADD'			=> '<strong>เพิ่มการกรองคำหยาบ</strong><br />? %s',
 	'LOG_WORD_DELETE'		=> '<strong>ลบการกรองคำหยาบ</strong><br />? %s',
