@@ -1,7 +1,7 @@
 <?php
 /** 
-* ภาษาไทย เวอร์ชั่น 1.1.1 
-* 07/01/2554 
+* ภาษาไทย เวอร์ชั่น 1.3.0 
+* 27/08/2555 
 * ไฟล์ภาษาไทยสำหรับ PHPBB3 โดย www.mindphp.com และ www.phpbbthailand.com
 *
 */ 
@@ -184,7 +184,7 @@ $lang = array_merge($lang, array(
 	'ROLE_FORUM_READONLY'		=> 'เข้าใช้งานแบบอ่านได้อย่างเดียว',
 	'ROLE_FORUM_STANDARD'		=> 'ค่ามาตรฐานการเข้าใช้งาน',
 
-	'ROLE_FORUM_NEW_MEMBER'		=> 'ผู้ใช้ใหม่ที่เพิ่งลงทะเบียนเสร็จ',
+	'ROLE_FORUM_NEW_MEMBER'		=> 'การเข้าใช้งานของผู้ใช้ใหม่ที่เพิ่งลงทะเบียนเสร็จ',
 	
 	'ROLE_MOD_FULL'				=> 'Full Moderator',
 	'ROLE_MOD_QUEUE'			=> 'Queue Moderator',
@@ -196,7 +196,7 @@ $lang = array_merge($lang, array(
 	'ROLE_USER_NOPM'			=> 'ไม่มีข้อความส่วนตัว',
 	'ROLE_USER_STANDARD'		=> 'Standard Features',
 
-	'ROLE_USER_NEW_MEMBER'		=> 'ผู้ใช้ใหม่ที่เพิ่งลงทะเบียนเสร็จ',
+	'ROLE_USER_NEW_MEMBER'		=> 'Features ของผู้ใช้ใหม่ที่เพิ่งลงทะเบียนเสร็จ',
 
 	'ROLE_DESCRIPTION_ADMIN_FORUM'			=> 'สามารถเข้าถึงการจัดการบอร์ด จัดการบอร์ด และการตั้งค่าอนุญาตบอร์ด',
 	'ROLE_DESCRIPTION_ADMIN_FULL'			=> 'มีความสามารถเข้าถึงฟังก์ชันการดูแลระบบบอร์ดทั้งหมด<br /> ไม่แนะนำให้ใช้',
@@ -212,7 +212,7 @@ $lang = array_merge($lang, array(
 	'ROLE_DESCRIPTION_FORUM_READONLY'		=> 'สามารถอ่านบอร์ด ได้แต่ไม่สามารถสร้างกระทู้หรือตอบโพสต์ได้',
 	'ROLE_DESCRIPTION_FORUM_STANDARD'		=> 'สามารถใช้ features รวมทั้ง ไฟล์แนบและลบกระทู้ตนเอง แต่ไม่สามารถล็อกกระทู้ตัวเองได้ และสามารถสร้างแบบสำรวจ',
 
-	'ROLE_DESCRIPTION_FORUM_NEW_MEMBER'		=> 'กฏสำหรับกลุ่มสมาชิกที่เพิ่งลงทะเบียนเสร็จ; คือ <samp>NEVER</samp> permissions to lock features for new users.',
+	'ROLE_DESCRIPTION_FORUM_NEW_MEMBER'		=> 'กฏสำหรับกลุ่มสมาชิกที่เพิ่งลงทะเบียนเสร็จ; คือ <samp>อย่า</samp> จำกัด features สำหรับผู้ใช้ใหม่.',
 	
 	'ROLE_DESCRIPTION_MOD_FULL'				=> 'สามารถใช้ moderating features ทั้งหมด รวมทั้งการแบน',
 	'ROLE_DESCRIPTION_MOD_QUEUE'			=> 'สามารถใช้ Moderation Queue เพื่อตรวจสอบและแก้ไขโพสต์เท่านั้น',
@@ -224,7 +224,7 @@ $lang = array_merge($lang, array(
 	'ROLE_DESCRIPTION_USER_NOPM'			=> 'มีการใช้ feature ที่จำกัดและไม่อนุญาตให้ใช้ ข้อความส่วนตัว',
 	'ROLE_DESCRIPTION_USER_STANDARD'		=> 'สามารถใช้ features ส่วนใหญ่แต่ไม่ทั้งหมด เช่น ไม่สามารถเปลี่ยนชื่อผู้ใช้หรือละเลย flood limit',
 	
-	'ROLE_DESCRIPTION_USER_NEW_MEMBER'		=> 'A role for members of the special newly registered users group; contains <samp>NEVER</samp> permissions to lock features for new users.',
+	'ROLE_DESCRIPTION_USER_NEW_MEMBER'		=> 'กฏสำหรับกลุ่มสมาชิกที่เพิ่งลงทะเบียนเสร็จ; คือ <samp>อย่า</samp> จำกัด features สำหรับผู้ใช้ใหม่.',
 	
 	'ROLE_DESCRIPTION_EXPLAIN'		=> 'คุณสามารถกรอกคำอธิบายสั้นๆ ว่าบทบาทนี้ทำอะไรบ้างและมีไว้เพื่ออะไร ข้อความที่คุณกรอกจะแสดงในหน้าจอการอนุญาตด้วย',
 	'ROLE_DESCRIPTION_LONG'			=> 'คำอธิบายบทบาทยาวเกินไป จำกัดอยู่ที่ 4000 ตัวอักษร',
@@ -263,17 +263,17 @@ $lang = array_merge($lang, array(
 	'TRACE_GROUP_YES_TOTAL_YES'		=> 'การอนุญาตของกลุ่มนี้ถูกตั้งค่าเป็น <samp>ได้</samp>และ การอนุญาตทั้งหมดเป็น <samp>ได้</samp> ดังนั้นค่าทั้งหมดจึงถูกเก็บไว้',
 	'TRACE_GROUP_YES_TOTAL_YES_LOCAL'	=> 'การอนุญาตของกลุ่มสำหรับบอร์ด นี้ถูกตั้งค่าเป็น <samp>ได้</samp>และการอนุญาตทั้งหมดเป็น<samp>YES</samp>ดังนั้นค่าทั้งหมดจึงถูกเก็บไว้',
 	'TRACE_PERMISSION'				=> 'ติดตามการอนุญาต - %s',
-	'TRACE_RESULT'					=> 'Trace result',
-	'TRACE_SETTING'					=> 'Trace setting',
+	'TRACE_RESULT'					=> 'ผลการติดตาม',
+	'TRACE_SETTING'					=> 'การตั้งค่าการติดตาม',
+
+	'TRACE_USER_GLOBAL_YES_TOTAL_YES'		=> 'การอนุญาตผู้ใช้อิสระของบอร์ดถูกประเมินให้เป็น <samp>YES</samp> แต่การอนุญาตทั้งหมดถูกตั้งให้เป็น <samp>YES</samp> อยุ่แล้ว, ดังนั้นผลลัพธ์ทั้งหมดถูกเก็บ. %sTrace global permission%s',
+	'TRACE_USER_GLOBAL_YES_TOTAL_NEVER'		=> 'การอนุญาตผู้ใช้อิสระของบอร์ดถูกประเมินให้เป็น <samp>YES</samp> ซึ่งแทนที่ผลลัพธ์ local permission ปัจจุบัน <samp>NEVER</samp>. %sTrace global permission%s',
+	'TRACE_USER_GLOBAL_NEVER_TOTAL_KEPT'	=> 'การอนุญาตผู้ใช้อิสระของบอร์ดถูกประเมินให้เป็น <samp>NEVER</samp> ซึ่งไม่ได้ส่งผลกระทบกับ local permission. %sTrace global permission%s',
 
-	'TRACE_USER_GLOBAL_YES_TOTAL_YES'		=> 'The forum independent user permission evaluates to <samp>YES</samp> but the total permission is already set to <samp>YES</samp>, so the total result is kept. %sTrace global permission%s',
-	'TRACE_USER_GLOBAL_YES_TOTAL_NEVER'		=> 'The forum independent user permission evaluates to <samp>YES</samp> which overwrites the current local result <samp>NEVER</samp>. %sTrace global permission%s',
-	'TRACE_USER_GLOBAL_NEVER_TOTAL_KEPT'	=> 'The forum independent user permission evaluates to <samp>NEVER</samp> which doesn’t influence the local permission. %sTrace global permission%s',
-/*
 	'TRACE_USER_FOUNDER'					=> 'ผู้ใช้เป็นประเภทผู้ก่อตั้ง, ดังนั้นสิทธิ์ผู้ดูแลระบบจึงถูกตั้งค่าเป็น <samp>YES</samp> โดยค่าเริ่มต้น',
-*/
+/*
 	'TRACE_USER_FOUNDER'					=> 'The user is a founder, therefore admin permissions are always set to <samp>YES</samp>.',
-	
+*/	
 	'TRACE_USER_KEPT'						=> 'การอนุญาตผู้ใช้เป็น <samp>ไม่ได้</samp> ค่าเก่าจะถูกเก็บไว้.',
 	'TRACE_USER_KEPT_LOCAL'					=> 'การอนุญาตผู้ใช้ สำหรับบอร์ดนี้เป็น <samp>ไม่ได้</samp> ค่าเก่าจะถูกเก็บไว้.',
 	'TRACE_USER_NEVER_TOTAL_NEVER'			=> 'การอนุญาตผู้ใช้เป็น <samp>ไม่ได้เด็ดขาด</samp>และค่าทั้งหมดถูกตั้งค่าเป็น <samp>NEVER</samp>ดังนั้นไม่มีการเปลี่ยนแปลง',
@@ -293,7 +293,7 @@ $lang = array_merge($lang, array(
 	'TRACE_WHO'								=> 'ใคร',
 	'TRACE_TOTAL'							=> 'รวม',
 
-	'USERS_NOT_ASSIGNED'			=> 'ไม่มีผู้ใช้กำหนดบทบาทนี้',
+	'USERS_NOT_ASSIGNED'			=> 'ไม่มีผู้ใช้คนใดถูกกำหนดบทบาทนี้',
 	'USER_IS_MEMBER_OF_DEFAULT'		=> 'สมาชิกตามนี้จะถูกกำหนด ให้อยู่ในกลุ่ม',
 	'USER_IS_MEMBER_OF_CUSTOM'		=> 'คือสมาชิกที่กำหนดไว้ถายในกลุ่ม',
 
