@@ -1,7 +1,7 @@
 <?php
 /** 
-* ภาษาไทย เวอร์ชั่น 1.2.3 
-* 05/06/2553 
+* ภาษาไทย เวอร์ชั่น 1.2.5 
+* 27/08/2555 
 * ไฟล์ภาษาไทยสำหรับ PHPBB3 โดย www.mindphp.com และ www.phpbbthailand.com
 *
 */ 
@@ -50,8 +50,8 @@ $lang = array_merge($lang, array(
 	'ACP_BBCODES_EXPLAIN'		=> 'BBCode เป็นการใช้ HTML แบบพิเศษ ทำให้สามารถควบคุมการแสดงผลได้อย่างดี. ภายในหน้านี้ คุณสามารถเพิ่ม, ลบ และแก้ไข custom BBCodes.',
 	'ADD_BBCODE'				=> 'เพิ่ม BBCode',
 
-	'BBCODE_DANGER'				=> 'The BBCode you are trying to add seems to use a {TEXT} token inside a HTML attribute. This is a possible XSS security issue. Try using the more restrictive {SIMPLETEXT} or {INTTEXT} types instead. Only proceed if you understand the risks involved and you consider the use of {TEXT} absolutely unavoidable.',
-	'BBCODE_DANGER_PROCEED'		=> 'Proceed', //'I understand the risk',
+	'BBCODE_DANGER'				=> 'BBCode ที่คุณกำลังพยายามเพิ่มดูเหมือนว่าจะใช้สัญลักษณ์ {TEXT} ภายใน HTML attribute. นี้อาจเป็นปัญหาความปลอดภัย XSS. ลองใช้แบบที่จำกัด {SIMPLETEXT} or {INTTEXT} มากกว่านี้. ดำเนินการต่อเมื่อคุณเข้าใจความเสี่ยงเกี่ยวและคุณพิจารณาที่จะใช้ {TEXT} อย่างที่หลีกเลี่ยงไม่ได้.',
+	'BBCODE_DANGER_PROCEED'		=> 'ดำเนินการ', //'I understand the risk',
 
 	'BBCODE_ADDED'				=> 'เพิ่ม BBCode สำเร็จ',
 	'BBCODE_EDITED'				=> 'แก้ไข BBCode สำเร็จ',
@@ -105,25 +105,25 @@ $lang = array_merge($lang, array(
 	'ADD_SMILIES'			=> 'เพิ่ม smilies ทีละหลายอัน',
 	'ADD_SMILEY_CODE'		=> 'เพิ่ม additional smiley code',
 	'ADD_ICONS'				=> 'เพิ่ม icons ทีละหลายอัน',
-	'AFTER_ICONS'			=> 'After %s',
-	'AFTER_SMILIES'			=> 'After %s',
+	'AFTER_ICONS'			=> 'หลัง %s',
+	'AFTER_SMILIES'			=> 'หลัง %s',
 
-	'CODE'						=> 'Code',
-	'CURRENT_ICONS'				=> 'Current icons',
+	'CODE'						=> 'โค้ต',
+	'CURRENT_ICONS'				=> 'icons ปัจจุบัน',
 	'CURRENT_ICONS_EXPLAIN'		=> 'เลือก ว่าจะทำอะไรกับ icons.',
-	'CURRENT_SMILIES'			=> 'Current smilies',
+	'CURRENT_SMILIES'			=> 'smilies ปัจจุบัน',
 	'CURRENT_SMILIES_EXPLAIN'	=> 'เลือก ว่าจะทำอะไรกับ smilies.',
 
-	'DISPLAY_ON_POSTING'		=> 'Display on posting page',
-	'DISPLAY_POSTING'			=> 'On posting page',
-	'DISPLAY_POSTING_NO'		=> 'Not on posting page',
+	'DISPLAY_ON_POSTING'		=> 'แสดงบนหน้าโพส',
+	'DISPLAY_POSTING'			=> 'บนหน้าโพส',
+	'DISPLAY_POSTING_NO'		=> 'ไม่บนหน้าโพส',
 
 
 	
 	'EDIT_ICONS'				=> 'แก้ไข icons',
 	'EDIT_SMILIES'				=> 'แก้ไข smilies',
 	'EMOTION'					=> 'Emotion',
-	'EXPORT_ICONS'				=> 'ส่งออกและดาวน์โหลด icons package ',
+	'EXPORT_ICONS'				=> 'ส่งออกและดาวน์โหลดชุด icons',
 	'EXPORT_ICONS_EXPLAIN'		=> '%sเมื่อคลิกลิงค์นี้,ไอคอนที่ติดตั้งจะถูกห่อเป็น <samp>icons.pak</samp> ซึ่งเมื่อดาวน์โหลด สามารถใช้สร้างเป็น <samp>.zip</samp> หรือ <samp>.tgz</samp> รวมทั้งไฟล์ปรับแต่ง%s.',
 	'EXPORT_SMILIES'			=> 'นำออกและดาวน์โหลด smilies.pak',
 	'EXPORT_SMILIES_EXPLAIN'	=> '%sเมื่อคลิกลิงค์นี้, smilies ที่ติดตั้งจะถูกห่อเป็น <samp>smilies.pak</samp> ซึ่งเมื่อดาวน์โหลด สามารถใช้สร้างเป็น <samp>.zip</samp> หรือ <samp>.tgz</samp> รวมทั้งไฟล์ปรับแต่ง%s.',
@@ -134,25 +134,25 @@ $lang = array_merge($lang, array(
 	'ICONS_NONE_ADDED'		=> 'ไม่มีไอคอนใดถูกเพิ่ม',
 	'ICONS_ONE_ADDED'		=> 'เพิ่มไอคอนสำเร็จ',
 	'ICONS_ADDED'			=> 'เพิ่มไอคอนสำเร็จ',
-	'ICONS_CONFIG'			=> 'Icon configuration',
+	'ICONS_CONFIG'			=> 'การตั้งค่า Icon',
 	'ICONS_DELETED'			=> 'ลบไอคอนสำเร็จ',
 	'ICONS_EDIT'			=> 'แก้ไขไอคอน',
 	'ICONS_ONE_EDITED'		=> 'อัพเดทไอคอนสำเร็จ',
 	'ICONS_NONE_EDITED'		=> 'ไม่มีไอคอนใดถูกอัพเดท',
 	'ICONS_EDITED'			=> 'อัพเดทไอคอนสำเร็จ',
-	'ICONS_HEIGHT'			=> 'Icon height',
-	'ICONS_IMAGE'			=> 'Icon image',
+	'ICONS_HEIGHT'			=> 'ความสูง Icon',
+	'ICONS_IMAGE'			=> 'รูปภาพ Icon',
 	'ICONS_IMPORTED'		=> 'ไอคอนแพคติดตั้งสำเร็จ.',
 	'ICONS_IMPORT_SUCCESS'	=> 'นำเข้าไอคอนสำเร็จ.',
-	'ICONS_LOCATION'		=> 'Icon location',
+	'ICONS_LOCATION'		=> 'ที่ตั้ง Icon',
 	'ICONS_NOT_DISPLAYED'	=> 'ไอคอนต่อไปนี้ไม่ถูกแสดง',
-	'ICONS_ORDER'			=> 'Icon order',
-	'ICONS_URL'				=> 'Icon image file',
-	'ICONS_WIDTH'			=> 'Icon width',
+	'ICONS_ORDER'			=> 'การจัดลำดับ Icon',
+	'ICONS_URL'				=> 'ไฟล์รูป Icon',
+	'ICONS_WIDTH'			=> 'ความกว้าง Icon',
 	'IMPORT_ICONS'			=> 'ติดตั้งกลุ่มไอคอน',
 	'IMPORT_SMILIES'		=> 'ติดตั้งกลุ่มรูปแสดงอารมณ์',
 
-	'KEEP_ALL'			=> 'Keep all',
+	'KEEP_ALL'			=> 'เก็บทั้งหมด',
 
 	'MASS_ADD_SMILIES'	=> 'เพิ่มรูปแสดงอารมณ์ทีละหลายอัน',
 
@@ -163,9 +163,9 @@ $lang = array_merge($lang, array(
 	'NO_SMILIES_ADD'	=> 'ไม่มี รูปแสดงอารมณ์ สำหรับการเพิ่ม',
 	'NO_SMILIES_EDIT'	=> 'ไม่มีรูปแสดงอารมณ์ สำหรับการปรับแต่ง',
 
-	'SMILIE_NO_CODE'			=> 'The smiley “%s” was ignored, as there was no code entered.',
-	'SMILIE_NO_EMOTION'			=> 'The smiley “%s” was ignored, as there was no emotion entered.',
-	'SMILIE_NO_FILE'			=> 'The smiley “%s” was ignored, as the file is missing.',
+	'SMILIE_NO_CODE'			=> 'smiley “%s” ถูกเพิกเฉย, เพราะไม่มีโค้ตสำหรับใส่ Smile นี้.',
+	'SMILIE_NO_EMOTION'			=> 'smiley “%s” ถูกเพิกเฉย, พราะไม่มีโค้ตสำหรับใส่ emotion นี้.',
+	'SMILIE_NO_FILE'			=> 'smiley “%s” ถูกเพิกเฉย, เพราะไม่สามารถหาไฟล์ได้.',
 
 	'NO_SMILIES_EXPORT'	=> 'คุณไม่มีรูปแสดงอารมณ์ ที่จะใช้ในการสร้าง package.',
 	'NO_SMILIES_PAK'	=> 'ไม่พบกลุ่มรูปแสดงอารมณ์',
@@ -195,7 +195,7 @@ $lang = array_merge($lang, array(
 	'SMILIES_URL'				=> 'ไฟล์รูปแสดงอารมณ์',
 	'SMILIES_WIDTH'				=> 'ความกว้างรูปแสดงอารมณ์',
 
-	'TOO_MANY_SMILIES'			=> 'Limit of %d smilies reached.',
+	'TOO_MANY_SMILIES'			=> 'จำกัด %d smilies.',
 
 	'WRONG_PAK_TYPE'	=> 'กลุ่มที่ระบุ มีข้อมูลที่ไม่ถูกต้อง',
 ));
@@ -232,7 +232,7 @@ $lang = array_merge($lang, array(
 	'NO_UPDATE_RANKS'		=> 'การลบอันดับสำเร็จ อย่างไรก็ตาม ผู้ใช้ ที่ใช้อันดับนี้ยังไม่ถูกอัพเดท คุณต้องตั้งค่าใหม่เองกับผู้ใช้เหล่านี้',
 
 	'RANK_ADDED'			=> 'เพิ่มอันดับสำเร็จ',
-	'RANK_IMAGE'			=> 'Rank image',
+	'RANK_IMAGE'			=> 'รูปภาพ Rank',
 	'RANK_IMAGE_EXPLAIN'	=> 'ใช้ค่านี้เพื่อนิยามรูปภาพเล็กที่จับคู่กับอันดับ. เส้นทางจะสัมพันธ์กับไดเรกทอรี่ ของphpBB',
 
 	'RANK_IMAGE_IN_USE'		=> '(ใช้งานอยู่)',
@@ -274,19 +274,19 @@ $lang = array_merge($lang, array(
 	
 	'NO_REASON'					=> 'ไม่พบเหตุผล',
 	'NO_REASON_INFO'			=> 'คุณต้องระบุชื่อและคำอธิบายของเหตุผลนี้',
-	'NO_REMOVE_DEFAULT_REASON'	=> 'คุณไม่สามารถลบเหตุผล “Other”',
+	'NO_REMOVE_DEFAULT_REASON'	=> 'คุณไม่สามารถลบเหตุผล “อื่นๆ”',
 
-	'REASON_ADD'				=> 'เพิ่มเหตุผล report/denial ',
-	'REASON_ADDED'				=> 'เพิ่มเหตุผล Report/denialสำเร็จ',
+	'REASON_ADD'				=> 'เพิ่มเหตุผล รายงาน/การปฎิเสธ ',
+	'REASON_ADDED'				=> 'เพิ่มเหตุผล รายงาน/การปฎิเสธ สำเร็จ',
 	'REASON_ALREADY_EXIST'		=> 'เหตุผลที่มีชื่อนี้ มีอยู่แล้ว, กรุณาใส่ชื่อใหม่',
 	'REASON_DESCRIPTION'		=> 'คำอธิบายเหตุผล',
 	'REASON_DESC_TRANSLATED'	=> 'แสดงคำอธิบายเหตุผล',
-	'REASON_EDIT'				=> 'แก้ไขเหตุผล report/denial',
+	'REASON_EDIT'				=> 'แก้ไขเหตุผล รายงาน/การปฎิเสธ',
 	'REASON_EDIT_EXPLAIN'		=> 'คุณสามารถเพิ่มหรือแก้ไขเหตุผล. ถ้าเหตุผลถูกแปลแล้ว คำแปลจะถูกใช้แทนข้อความที่ระบุนี้',
-	'REASON_REMOVED'			=> 'ลบเหตุผล Report/denial สำเร็จ',
+	'REASON_REMOVED'			=> 'ลบเหตุผล Report/การปฎิเสธ สำเร็จ',
 	'REASON_TITLE'				=> 'ชื่อเหตุผล',
 	'REASON_TITLE_TRANSLATED'	=> 'แสดงชื่อเหตุผล',
-	'REASON_UPDATED'			=> 'อัพเดทเหตุผล Report/denial สำเร็จ',
+	'REASON_UPDATED'			=> 'อัพเดทเหตุผล รายงาน/การปฎิเสธ สำเร็จ',
 
 	'USED_IN_REPORTS'		=> 'ใช้ในรายงาน',
 ));
