@@ -1,7 +1,7 @@
 <?php
 /** 
-* ภาษาไทย เวอร์ชั่น 1.2.2
-* 23/11/2553  
+* ภาษาไทย เวอร์ชั่น 1.3.0
+* 27/08/2555  
 * ไฟล์ภาษาไทยสำหรับ PHPBB3 โดย www.mindphp.com และ www.phpbbthailand.com
 *
 */ 
@@ -68,8 +68,8 @@ $lang = array_merge($lang, array(
 	'CACHE'							=> 'Cache',
 	'CACHE_CACHED'					=> 'Cached',
 	'CACHE_FILENAME'				=> 'ไฟล์ Template ',
-	'CACHE_FILESIZE'				=> 'File size',
-	'CACHE_MODIFIED'				=> 'Modified',
+	'CACHE_FILESIZE'				=> 'ขนาดไฟล์',
+	'CACHE_MODIFIED'				=> 'ถูกปรับเปลี่ยน',
 	'CONFIRM_IMAGESET_REFRESH'		=> 'คุณแน่ใจที่จะ refresh imageset ทั้งหมด? การตั้งค่านี้ จะเขียนทับทุกการปรับแต่ง',
 	'CONFIRM_TEMPLATE_CLEAR_CACHE'	=> 'คุณแน่ใจที่จะ ลบทุกไฟล์เวอร์ชันของแคช Template ?',
 	'CONFIRM_TEMPLATE_REFRESH'		=> 'คุณแน่ใจที่จะ refresh ข้อมูล Template ทุกอันในฐานข้อมูล ด้วยเนื้อหาในไฟล์ Template บนระบบไฟล์? การกระทำนี้จะเขียนทับทุกการปรับแต่งที่ได้ทำไปแล้วในฐานข้อมูล.',
@@ -277,6 +277,7 @@ $lang = array_merge($lang, array(
 	'IMG_USER_ICON8'		=> 'ภาพผู้ใช้   8',
 	'IMG_USER_ICON9'		=> 'ภาพผู้ใช้    9',
 	'IMG_USER_ICON10'		=> 'ภาพผู้ใช้    10',
+        'INACTIVE_STYLES'               => 'สไตล์ที่ไม่ถูกใช้',
 
 	'INCLUDE_DIMENSIONS'		=> 'รวม ความกว้างยาว',
 	'INCLUDE_IMAGESET'			=> 'รวม imageset',
@@ -355,7 +356,7 @@ $lang = array_merge($lang, array(
 	'STYLE_ACTIVATE'			=> 'ทำให้ใช้งานได้',
 	'STYLE_ACTIVE'				=> 'ใช้งานอยู่',
 	'STYLE_ADDED'				=> 'เพิ่มรูปแบบเรียบร้อยแล้ว.',
-	'STYLE_DEACTIVATE'			=> 'ทำให้ใช้งานไม่ได้',
+	'STYLE_DEACTIVATE'			=> 'ยกเลิกการใช้งาน',
 	'STYLE_DEFAULT'				=> 'ทำให้เป็นรูปแบบเริ่มต้น',
 	'STYLE_DELETED'				=> 'ลบรูปแบบเรียบร้อยแล้ว.',
 	'STYLE_DETAILS_UPDATED'		=> 'แก้ไขรูปแบบเรียบร้อยแล้ว.',
@@ -436,7 +437,7 @@ $lang = array_merge($lang, array(
 	'THEME_LOCATION'			=> 'เก็บ stylesheet ไว้ใน',
 	'THEME_LOCATION_EXPLAIN'	=> 'ภาพจะเก็บในระบบไฟล์เสมอ',
 	'THEME_NAME'				=> 'ชื่อ Theme ',
-	'THEME_REFRESHED'			=> 'refresh Theme   เรียบร้อยแล้ว',
+	'THEME_REFRESHED'			=> 'refresh Theme เรียบร้อยแล้ว',
 	'THEME_UPDATED'				=> 'อัพเดท Theme เรียบร้อยแล้ว',
 
 	'UNDERLINE'				=> 'ขีดเส้นใต้',
