@@ -1,12 +1,12 @@
 <?php
 /** 
-* ภาษาไทย เวอร์ชั่น 1.3.2 
-* 06/01/2555
+* ภาษาไทย เวอร์ชั่น 1.3.6
+* 27/08/2555
 * ไฟล์ภาษาไทยสำหรับ PHPBB3 โดย www.mindphp.com และ www.phpbbthailand.com
 * posting [Thai]
 */ 
 
-/**
+/*
 * DO NOT CHANGE
 */
 if (!defined('IN_PHPBB'))
@@ -27,6 +27,7 @@ $lang = array_merge($lang, array(
 	'ADD_POLL'					=> 'แบบสอบถาม',
 	'ADD_POLL_EXPLAIN'			=> 'หากคุณไม่ต้องการเพิ่มแบบสอบถาม กรุณาปล่อยกล่องข้อความหัวข้อให้ค่าว่างไว้',
 	'ALREADY_DELETED'			=> 'ขออภัยคุณไม่สามารถลบข้อความนี้ได้',
+        'ATTACH_DISK_FULL'			=> 'ไม่มีพื้นที่เพียงพอสำหรับโพสไฟล์แนบนี้',
 	'ATTACH_QUOTA_REACHED'		=> 'ไฟล์ที่อัพโหลดขึ้นมา มีขนาดใหญ่เกินไป',
 	'ATTACH_SIG'				=> 'แนบลายเซ็นต์ (แก้ไขลายเซ็นต์ได้ที่หน้า แก้ไขข้อมูลส่วนตัว)',
 
@@ -62,7 +63,7 @@ $lang = array_merge($lang, array(
 	'DELETE_MESSAGE'			=> 'ลบข้อความ',
 	'DELETE_MESSAGE_CONFIRM'	=> 'ต้องการลบข้อความนี้ ?',
 	'DELETE_OWN_POSTS'			=> 'ขออภัยคะ คุณสามารถลบข้อความได้แต่ข้อความที่คุณเป็นเจ้าของเท่านั้น',
-	'DELETE_POST_CONFIRM'		=> '่ต้องการลบข้อความนี้?',
+	'DELETE_POST_CONFIRM'		=> 'ต้องการลบข้อความนี้?',
 	'DELETE_POST_WARN'			=> 'หากลบข้อความแล้วไม่สามารถกู้คืนได้',
 	'DISABLE_BBCODE'			=> 'ไม่ใช้ BBCode ในข้อความนี้',
 	'DISABLE_MAGIC_URL'			=> 'ไม่ต้องแปลง URL ให้เป็นลิงค์',
@@ -91,7 +92,7 @@ $lang = array_merge($lang, array(
 	'FONT_SMALL'				=> 'เล็ก',
 	'FONT_TINY'					=> 'เล็กมาก',
 
-	'GENERAL_UPLOAD_ERROR'		=> '่สามารถอัพโหลดไฟล์ %s.',
+	'GENERAL_UPLOAD_ERROR'		=> 'สามารถอัพโหลดไฟล์ %s.',
 
 	'IMAGES_ARE_OFF'			=> '[img] <em>ปิด</em>',
 	'IMAGES_ARE_ON'				=> '[img] <em>เปิด</em>',
