@@ -1,7 +1,7 @@
 <?php
 /** 
-* ภาษาไทย เวอร์ชั่น 1.3.3 
-* 06/01/25535 
+* ภาษาไทย เวอร์ชั่น 1.3.5 
+* 27/08/2555 
 * ไฟล์ภาษาไทยสำหรับ PHPBB3 โดย www.mindphp.com และ www.phpbbthailand.com
 *
 */ 
@@ -79,7 +79,7 @@ $lang = array_merge($lang, array(
 	'ADD_RULE'						=> 'เพิ่มกฎ',
 	'ADD_TO'						=> 'เพิ่ม [ถึง]',
 
-	'ADD_USERS_UCP_EXPLAIN'			=> 'Here you can add new users to the group. You may select whether this group becomes the new default for the selected users. Please enter each username on a separate line.',
+	'ADD_USERS_UCP_EXPLAIN'			=> 'ที่นี่คุณสามารถแอดผู้ใช้ใหม่ไปยังกลุ่ม. คุณอาจเลือกให้กลุ่มนี้เป็นกลุ่มตั้งต้นสำหรับผู้ใช้ที่เลือก. โปรดใส่ชื่อ username ของแต่ละคนบรรทัดละหนึ่งชื่อ.',
 	
 	'ADMIN_EMAIL'					=> 'ผู้ดูแลระบบสามารถส่งเมลมาหาได้',
 	'AGREE'							=> 'ยอมรับเงื่อนไข',
@@ -142,6 +142,7 @@ $lang = array_merge($lang, array(
 	'CURRENT_IMAGE'				=> 'รูปภาพที่คุณใช้อยู่',
 	'CURRENT_PASSWORD'			=> 'รหัสผ่านปัจจุบัน',
 	'CURRENT_PASSWORD_EXPLAIN'	=> 'คุณต้องใส่รหัสผ่านปัจจุบันของคุณทุกครั้ง ที่มีการเปลี่ยนแปลง ชื่อผู้ใช้งาน อีเมล์ และรหัสผ่าน',
+        'CURRENT_CHANGE_PASSWORD_EXPLAIN' => 'ในการที่จะเปลี่ยนรหัสผ่าน, อีเมล์ หรือ ชื่อผู้ใช้งานของคุณ คุณจำเป็นต้องใส่รหัสผ่านปัจจุบัน',
 	'CUR_PASSWORD_EMPTY'		=> 'คุณยังไม่ได้กรอกรหัสผ่าน.',
 	'CUR_PASSWORD_ERROR'		=> 'คุณใส่รหัสผ่านปัจจุบันไม่ถูกต้อง.',
 	'CUSTOM_DATEFORMAT'			=> 'ตั้งค่าเอง…',
@@ -242,7 +243,7 @@ $lang = array_merge($lang, array(
 	'INVALID_USER_BIRTHDAY'			=> 'วันเกิดป้อนไม่ถูกต้อง วันที่ผิดพลาด.',	
 	'INVALID_CHARS_USERNAME'	=> 'ในชื่อผู้ใช้มีตัวอักษรที่ไม่ได้รับอนุญาตให้ใช้',
 	'INVALID_CHARS_NEW_PASSWORD'=> 'รหัสผ่านประกอบด้วยตัวอักษรที่ไม่ได้รับอนุญาตให้ใช้',
-	'NEW_PASSWORD_CONFIRM_EMPTY'	=> 'คุุณยังไม่ได้กรอก confirm password.',
+	'NEW_PASSWORD_CONFIRM_EMPTY'	=> 'คุณยังไม่ได้กรอก ยืนยันรหัสผ่าน.',
 	'ITEMS_REQUIRED'			=> 'ข้อมูลที่ระบุเครื่องหมาย  * เป็นข้อมูลที่จำเป็นต้องกรอก',
 
 	'JOIN_SELECTED'				=> 'ขอเข้าร่วมกลุ่ม',
@@ -276,7 +277,7 @@ $lang = array_merge($lang, array(
 	'MOVE_PM_ERROR'					=> 'เกิดข้อผิดพลาดขณะย้ายข้อความเข้าโฟลเดอร์ใหม่ เพียง %1d จาก %2d ที่คุณต้องการย้าย.',
 	'MOVE_TO_FOLDER'				=> 'ย้ายไปยังโฟล์เดอร์',
 	'MOVE_UP'						=> 'เลื่อนขึ้น',
-	'NEW_EMAIL_CONFIRM_EMPTY'		=> 'คุณยังไม่ได้กรอก a confirm e-mail .',
+	'NEW_EMAIL_CONFIRM_EMPTY'		=> 'คุณยังไม่ได้กรอก อีเมลยืนยัน .',
 
 	'NEW_EMAIL_ERROR'				=> 'อีเมล์ยืนยันไม่ตรงกัน โปรดตรวจสอบอีกครั้ง',
 	'NEW_FOLDER_NAME'				=> 'ชื่อโฟล์เดอร์',
@@ -290,14 +291,14 @@ $lang = array_merge($lang, array(
 	'NOTIFY_ON_PM'					=> 'แจ้งเตือนเมื่อมีข้อความส่วนตัวมาใหม่',
 	'NOT_ADDED_FRIENDS_ANONYMOUS'	=> 'คุณไม่สามารถเพิ่มรายชื่อที่ไม่มีตัวตน ลงในรายชื่อเพื่อนได้.',
 
-	'NOT_ADDED_FRIENDS_BOTS'		=> 'ไม่สามารถเพิ่้มบอทเข้าสู่รายชื่อเพื่อนได้.',
+	'NOT_ADDED_FRIENDS_BOTS'		=> 'ไม่สามารถเพิ่มบอทเข้าสู่รายชื่อเพื่อนได้.',
 
 	'NOT_ADDED_FRIENDS_FOES'		=> 'สมาชิกนี้อยู่ในรายชื่อของศัตรู ไม่สามารถเพิ่มในรายชื่อเพื่อนได้',
 	'NOT_ADDED_FRIENDS_SELF'		=> 'คุณไม่สามารถเพิ่มชื่อของคุณ ลงในรายชื่อเพื่อนได้',
 	'NOT_ADDED_FOES_MOD_ADMIN'		=> 'คุณไม่สามารถเพิ่มชื่อ ผู้ดูแล หรือ administrator ลงในรายชื่อศัตรูได้',
 	'NOT_ADDED_FOES_ANONYMOUS'		=> 'คุณไม่สามารถเพิ่มชื่อผู้ใช้ลงรายชื่อศัตรูได้',
 
-	'NOT_ADDED_FOES_BOTS'			=> 'ไม่สามารถเพิ่้มบอทเข้าสู่รายชื่อศัตรูได้.',
+	'NOT_ADDED_FOES_BOTS'			=> 'ไม่สามารถเพิ่มบอทเข้าสู่รายชื่อศัตรูได้.',
 	
 	'NOT_ADDED_FOES_FRIENDS'		=> 'สมาชิกนี้อยู่ในรายชื่อของเพื่อน ไม่สามารถเพิ่มในรายชื่อศัตรูได้',
 	'NOT_ADDED_FOES_SELF'			=> 'คุณไม่สามารถเพิ่มชื่อรายชื่อนิรนาม ลงในรายชื่อศัตรูได้',
@@ -400,6 +401,7 @@ $lang = array_merge($lang, array(
 	'RULE_ADDED'						=> 'เพิ่มกฏเรียบร้อยแล้ว',
 	'RULE_ALREADY_DEFINED'				=> 'กฏนี้ถูกใช้งานก่อนหน้าแล้ว',
 	'RULE_DELETED'						=> 'กฏถูกลบเรียบร้อยแล้ว.',
+        'RULE_LIMIT_REACHED'				=> 'คุณไม่สามารถเพิ่มกฎ PM. คุณได้มีจำนวนกฎถึงขีดจำกัดแล้ว',
 	'RULE_NOT_DEFINED'					=> 'กฎที่ระบุไม่ถูกต้อง',
 	'RULE_REMOVED_MESSAGE'				=> 'ข้อความส่วนตัวนี้ถูกลบเนื่องจากการกรองข้อความ.',
 	'RULE_REMOVED_MESSAGES'				=> '%d ข้อความส่วนตัวนี้ถูกลบเนื่องจากการกรองข้อความ.',
@@ -473,13 +475,13 @@ $lang = array_merge($lang, array(
 
 	'UCP_REGISTER_DISABLE'			=> 'ไม่สามารถสร้างบัญชีรายชื่อใหม่ได้ ณ ขณะนี้.',
 	'UCP_REMIND'					=> 'ส่งรหัสผ่าน',
-	'UCP_RESEND'					=> 'ส่ง E-mail',
+	'UCP_RESEND'					=> 'ส่งอีเมล์',
 	'UCP_WELCOME'					=> 'ยินดีต้อนรับเข้าสู่ส่วนการตั้งค่าสมาชิก. คุณสามารถตั้งค่าต่าง ๆ ของคุณจากเมนูนี้, ดูและอัปเดทข้อมูลส่วนตัว, ตั้งค่าการแสดงผลฟอรั่ม, รับ-ยกเลิก รับข่าวสารฟอรั่มและกระทู้. ส่งข้อความส่วนตัวไปยังสมาชิกท่านอื่น ๆ  (ถ้ามีการเปิดสิทธินั้นจาก Admin). หากคุณพร้อมแล้วก็สามารถเลือกและดำเนินการต่อไปได้เลย',
 	'UCP_YIM'						=> 'Yahoo Messenger',
 	'UCP_ZEBRA'						=> 'เพื่อนและศัตรู',
 	'UCP_ZEBRA_FOES'				=> 'รายชื่อศัตรู',
 	'UCP_ZEBRA_FRIENDS'				=> 'รายชื่อเพื่อน',
-	'UNDISCLOSED_RECIPIENT'			=> 'Undisclosed Recipient',	
+	'UNDISCLOSED_RECIPIENT'			=> 'ผู้รับที่ไม่เปิดเผย',	
 	'UNKNOWN_FOLDER'				=> 'ไม่รู้จักโฟรเดอร์นี้',
 	'UNWATCH_MARKED'				=> 'ยกเลิกการเค้ามอง',
 	'UPLOAD_AVATAR_FILE'			=> 'เลือกรูปจากเครื่องคุณ',
