@@ -37,7 +37,7 @@ if (empty($lang) || !is_array($lang))
 // in a url you again do not need to specify an order e.g., 'Click %sHERE%s' is fine
 
 $lang = array_merge($lang, array(
-	'ACTIVE_TOPICS'	=> 'Active topics',
+	'ACTIVE_TOPICS'	=> 'กระทู้ที่ยังถูกใช้งาน',
 	'ANNOUNCEMENTS'	=> 'ประกาศ',
 	'FORUM_PERMISSIONS'	=> 'การอนุญาตของคุณในบอร์ดนี้',
 	'ICON_ANNOUNCEMENT'	=> 'ประกาศ',
@@ -49,16 +49,15 @@ $lang = array_merge($lang, array(
 	'NO_NEW_POSTS_HOT'	=> 'ไม่มีโพสต์ใหม่ [ ยอดฮิต ]',
 	'NO_NEW_POSTS_LOCKED'	=> 'ไม่มีโพสต์ใหม่ [ ปิดหัวข้อ ]',
 	'NO_READ_ACCESS'	=> 'บอร์ดนี้สงวนสิททิ์ให้เฉพาะสมาชิกเท่านั้น กรุณาสมัครสมาชิกและเข้าสู่ระบบ !',
+	'NO_UNREAD_POSTS_HOT'		=> 'ไม่มีโพสต์ที่ยังไม่อ่าน [ เป็นที่นิยม ]',
+	'NO_UNREAD_POSTS_LOCKED'	=> 'ไม่มีโพสต์ที่ยังไม่อ่าน [ ล็อก ]',	
 	'POST_FORUM_LOCKED'	=> 'บอร์ดนี้ถูกล็อกไว้',
 	'TOPICS_MARKED'	=> 'บันทึกว่าอ่านทุกหัวข้อแล้ว',
+	'UNREAD_POSTS_HOT'		=> 'โพสต์ที่ยังไม่ได้อ่าน [ เป็นที่นิยม ]',
+	'UNREAD_POSTS_LOCKED'	=> 'โพสต์ที่ยังไม่ได้อ่าน [ ล็อก ]',	
 	'VIEW_FORUM'	=> 'บอร์ด',
 	'VIEW_FORUM_TOPIC'	=> '1 หัวข้อ',
 	'VIEW_FORUM_TOPICS'	=> '%d หัวข้อ',
-	'NO_UNREAD_POSTS_HOT'		=> 'No unread posts [ Popular ]',
-	'NO_UNREAD_POSTS_LOCKED'	=> 'No unread posts [ Locked ]',
-	'UNREAD_POSTS_HOT'		=> 'Unread posts [ Popular ]',
-	'UNREAD_POSTS_LOCKED'	=> 'Unread posts [ Locked ]',
-	
 ));
 
 ?>
\ No newline at end of file
